@@ -30,7 +30,7 @@ class InstalledVersions
     'aliases' => 
     array (
     ),
-    'reference' => 'a04e299b1d47d14c0676c7b1a2f270f12a11c313',
+    'reference' => 'c44299430013bae161dceb0ae71a20a8d44b8efd',
     'name' => '__root__',
   ),
   'versions' => 
@@ -42,7 +42,7 @@ class InstalledVersions
       'aliases' => 
       array (
       ),
-      'reference' => 'a04e299b1d47d14c0676c7b1a2f270f12a11c313',
+      'reference' => 'c44299430013bae161dceb0ae71a20a8d44b8efd',
     ),
     'beberlei/assert' => 
     array (
@@ -53,23 +53,14 @@ class InstalledVersions
       ),
       'reference' => 'cb70015c04be1baee6f5f5c953703347c0ac1655',
     ),
-    'bretterer/iso_duration_converter' => 
-    array (
-      'pretty_version' => 'v0.1.0',
-      'version' => '0.1.0.0',
-      'aliases' => 
-      array (
-      ),
-      'reference' => '1fa460fd9aec9853db812369a120cecfaf3d9c7b',
-    ),
     'brick/math' => 
     array (
-      'pretty_version' => '0.8.17',
-      'version' => '0.8.17.0',
+      'pretty_version' => '0.9.3',
+      'version' => '0.9.3.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'e6f8e7d04346a95be89580f8c2c22d6c3fa65556',
+      'reference' => 'ca57d18f028f84f777b2168cd1911b0dee2343ae',
     ),
     'christian-riesen/base32' => 
     array (
@@ -80,15 +71,6 @@ class InstalledVersions
       ),
       'reference' => '2e82dab3baa008e24a505649b0d583c31d31e894',
     ),
-    'clue/stream-filter' => 
-    array (
-      'pretty_version' => 'v1.6.0',
-      'version' => '1.6.0.0',
-      'aliases' => 
-      array (
-      ),
-      'reference' => 'd6169430c7731d8509da7aecd0af756a5747b78e',
-    ),
     'doctrine/inflector' => 
     array (
       'pretty_version' => '2.0.6',
@@ -118,21 +100,12 @@ class InstalledVersions
     ),
     'fgrosse/phpasn1' => 
     array (
-      'pretty_version' => 'v2.4.0',
-      'version' => '2.4.0.0',
+      'pretty_version' => 'v2.5.0',
+      'version' => '2.5.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'eef488991d53e58e60c9554b09b1201ca5ba9296',
-    ),
-    'firebase/php-jwt' => 
-    array (
-      'pretty_version' => 'v5.5.1',
-      'version' => '5.5.1.0',
-      'aliases' => 
-      array (
-      ),
-      'reference' => '83b609028194aa042ea33b5af2d41a7427de80e6',
+      'reference' => '42060ed45344789fb9f21f9f1864fc47b9e3507b',
     ),
     'guzzlehttp/psr7' => 
     array (
@@ -143,19 +116,19 @@ class InstalledVersions
       ),
       'reference' => 'e98e3e6d4f86621a9b75f623996e6bbdeb4b9318',
     ),
-    'illuminate/cache' => 
+    'http-interop/http-factory-guzzle' => 
     array (
-      'pretty_version' => 'v8.83.26',
-      'version' => '8.83.26.0',
+      'pretty_version' => '1.2.0',
+      'version' => '1.2.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => '7ae5b3661413dad7264b5c69037190d766bae50f',
+      'reference' => '8f06e92b95405216b237521cc64c804dd44c4a81',
     ),
     'illuminate/collections' => 
     array (
-      'pretty_version' => 'v8.83.26',
-      'version' => '8.83.26.0',
+      'pretty_version' => 'v8.83.27',
+      'version' => '8.83.27.0',
       'aliases' => 
       array (
       ),
@@ -163,8 +136,8 @@ class InstalledVersions
     ),
     'illuminate/contracts' => 
     array (
-      'pretty_version' => 'v8.83.26',
-      'version' => '8.83.26.0',
+      'pretty_version' => 'v8.83.27',
+      'version' => '8.83.27.0',
       'aliases' => 
       array (
       ),
@@ -172,8 +145,8 @@ class InstalledVersions
     ),
     'illuminate/macroable' => 
     array (
-      'pretty_version' => 'v8.83.26',
-      'version' => '8.83.26.0',
+      'pretty_version' => 'v8.83.27',
+      'version' => '8.83.27.0',
       'aliases' => 
       array (
       ),
@@ -181,8 +154,8 @@ class InstalledVersions
     ),
     'illuminate/pagination' => 
     array (
-      'pretty_version' => 'v8.83.26',
-      'version' => '8.83.26.0',
+      'pretty_version' => 'v8.83.27',
+      'version' => '8.83.27.0',
       'aliases' => 
       array (
       ),
@@ -190,8 +163,8 @@ class InstalledVersions
     ),
     'illuminate/support' => 
     array (
-      'pretty_version' => 'v8.83.26',
-      'version' => '8.83.26.0',
+      'pretty_version' => 'v8.83.27',
+      'version' => '8.83.27.0',
       'aliases' => 
       array (
       ),
@@ -217,39 +190,21 @@ class InstalledVersions
     ),
     'monolog/monolog' => 
     array (
-      'pretty_version' => '2.8.0',
-      'version' => '2.8.0.0',
+      'pretty_version' => '2.9.1',
+      'version' => '2.9.1.0',
       'aliases' => 
       array (
       ),
-      'reference' => '720488632c590286b88b80e62aa3d3d551ad4a50',
+      'reference' => 'f259e2b15fb95494c83f52d3caad003bbf5ffaa1',
     ),
     'nesbot/carbon' => 
     array (
-      'pretty_version' => '2.63.0',
-      'version' => '2.63.0.0',
+      'pretty_version' => '2.66.0',
+      'version' => '2.66.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'ad35dd71a6a212b98e4b87e97389b6fa85f0e347',
-    ),
-    'nyholm/psr7' => 
-    array (
-      'pretty_version' => '1.5.1',
-      'version' => '1.5.1.0',
-      'aliases' => 
-      array (
-      ),
-      'reference' => 'f734364e38a876a23be4d906a2a089e1315be18a',
-    ),
-    'okta/jwt-verifier' => 
-    array (
-      'pretty_version' => '1.4.0',
-      'version' => '1.4.0.0',
-      'aliases' => 
-      array (
-      ),
-      'reference' => '16f09cac583ab4d0e5ca53b1046dd3e6805244d7',
+      'reference' => '496712849902241f04902033b0441b269effe001',
     ),
     'paragonie/constant_time_encoding' => 
     array (
@@ -273,103 +228,42 @@ class InstalledVersions
     array (
       'provided' => 
       array (
-        0 => '1.0',
+        0 => '*',
       ),
     ),
-    'php-http/client-common' => 
-    array (
-      'pretty_version' => '2.6.0',
-      'version' => '2.6.0.0',
-      'aliases' => 
-      array (
-      ),
-      'reference' => '45db684cd4e186dcdc2b9c06b22970fe123796c0',
-    ),
     'php-http/client-implementation' => 
     array (
       'provided' => 
       array (
-        0 => '1.0',
+        0 => '*',
       ),
     ),
-    'php-http/curl-client' => 
-    array (
-      'pretty_version' => '2.2.1',
-      'version' => '2.2.1.0',
-      'aliases' => 
-      array (
-      ),
-      'reference' => '2ed4245a817d859dd0c1d51c7078cdb343cf5233',
-    ),
     'php-http/discovery' => 
     array (
-      'pretty_version' => '1.14.3',
-      'version' => '1.14.3.0',
+      'pretty_version' => '1.15.2',
+      'version' => '1.15.2.0',
       'aliases' => 
       array (
       ),
-      'reference' => '31d8ee46d0215108df16a8527c7438e96a4d7735',
-    ),
-    'php-http/httplug' => 
-    array (
-      'pretty_version' => '2.3.0',
-      'version' => '2.3.0.0',
-      'aliases' => 
-      array (
-      ),
-      'reference' => 'f640739f80dfa1152533976e3c112477f69274eb',
-    ),
-    'php-http/message' => 
-    array (
-      'pretty_version' => '1.13.0',
-      'version' => '1.13.0.0',
-      'aliases' => 
-      array (
-      ),
-      'reference' => '7886e647a30a966a1a8d1dad1845b71ca8678361',
-    ),
-    'php-http/message-factory' => 
-    array (
-      'pretty_version' => 'v1.0.2',
-      'version' => '1.0.2.0',
-      'aliases' => 
-      array (
-      ),
-      'reference' => 'a478cb11f66a6ac48d8954216cfed9aa06a501a1',
-    ),
-    'php-http/message-factory-implementation' => 
-    array (
-      'provided' => 
-      array (
-        0 => '1.0',
-      ),
-    ),
-    'php-http/promise' => 
-    array (
-      'pretty_version' => '1.1.0',
-      'version' => '1.1.0.0',
-      'aliases' => 
-      array (
-      ),
-      'reference' => '4c4c1f9b7289a2ec57cde7f1e9762a5789506f88',
+      'reference' => '5cc428320191ac1d0b6520034c2dc0698628ced5',
     ),
     'phpmailer/phpmailer' => 
     array (
-      'pretty_version' => 'v6.6.5',
-      'version' => '6.6.5.0',
+      'pretty_version' => 'v6.8.0',
+      'version' => '6.8.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => '8b6386d7417526d1ea4da9edb70b8352f7543627',
+      'reference' => 'df16b615e371d81fb79e506277faea67a1be18f1',
     ),
     'phpseclib/phpseclib' => 
     array (
-      'pretty_version' => '3.0.17',
-      'version' => '3.0.17.0',
+      'pretty_version' => '3.0.19',
+      'version' => '3.0.19.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'dbc2307d5c69aeb22db136c52e91130d7f2ca761',
+      'reference' => 'cc181005cf548bfd8a4896383bb825d859259f95',
     ),
     'psr/container' => 
     array (
@@ -393,7 +287,8 @@ class InstalledVersions
     array (
       'provided' => 
       array (
-        0 => '1.0',
+        0 => '*',
+        1 => '1.0',
       ),
     ),
     'psr/http-factory' => 
@@ -409,7 +304,8 @@ class InstalledVersions
     array (
       'provided' => 
       array (
-        0 => '1.0',
+        0 => '*',
+        1 => '^1.0',
       ),
     ),
     'psr/http-message' => 
@@ -426,6 +322,7 @@ class InstalledVersions
       'provided' => 
       array (
         0 => '1.0',
+        1 => '*',
       ),
     ),
     'psr/http-server-handler' => 
@@ -471,13 +368,6 @@ class InstalledVersions
       ),
       'reference' => '408d5eafb83c57f6365a3ca330ff23aa4a5fa39b',
     ),
-    'psr/simple-cache-implementation' => 
-    array (
-      'provided' => 
-      array (
-        0 => '1.0',
-      ),
-    ),
     'ralouphie/getallheaders' => 
     array (
       'pretty_version' => '3.0.3',
@@ -487,20 +377,29 @@ class InstalledVersions
       ),
       'reference' => '120b605dfeb996808c31b6477290a714d356e822',
     ),
-    'ramsey/uuid' => 
+    'ramsey/collection' => 
     array (
-      'pretty_version' => '3.9.6',
-      'version' => '3.9.6.0',
+      'pretty_version' => '1.3.0',
+      'version' => '1.3.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'ffa80ab953edd85d5b6c004f96181a538aad35a3',
+      'reference' => 'ad7475d1c9e70b190ecffc58f2d989416af339b4',
+    ),
+    'ramsey/uuid' => 
+    array (
+      'pretty_version' => '4.2.3',
+      'version' => '4.2.3.0',
+      'aliases' => 
+      array (
+      ),
+      'reference' => 'fc9bb7fb5388691fd7373cd44dcb4d63bbcf24df',
     ),
     'rhumsaa/uuid' => 
     array (
       'replaced' => 
       array (
-        0 => '3.9.6',
+        0 => '4.2.3',
       ),
     ),
     'spomky-labs/base64url' => 
@@ -514,12 +413,12 @@ class InstalledVersions
     ),
     'spomky-labs/cbor-php' => 
     array (
-      'pretty_version' => 'v1.1.1',
-      'version' => '1.1.1.0',
+      'pretty_version' => 'v2.1.0',
+      'version' => '2.1.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'b8e51e6a13606ab1dd8a64aa295651d8ad57ccd1',
+      'reference' => '28e2712cfc0b48fae661a48ffc6896d7abe83684',
     ),
     'symfony/deprecation-contracts' => 
     array (
@@ -530,6 +429,31 @@ class InstalledVersions
       ),
       'reference' => 'e8b495ea28c1d97b5e0c121748d6f9b53d075c66',
     ),
+    'symfony/http-client' => 
+    array (
+      'pretty_version' => 'v5.4.21',
+      'version' => '5.4.21.0',
+      'aliases' => 
+      array (
+      ),
+      'reference' => '6b88914a7f1bf144df15904f60a19be78a67a3b2',
+    ),
+    'symfony/http-client-contracts' => 
+    array (
+      'pretty_version' => 'v2.5.2',
+      'version' => '2.5.2.0',
+      'aliases' => 
+      array (
+      ),
+      'reference' => 'ba6a9f0e8f3edd190520ee3b9a958596b6ca2e70',
+    ),
+    'symfony/http-client-implementation' => 
+    array (
+      'provided' => 
+      array (
+        0 => '2.4',
+      ),
+    ),
     'symfony/http-foundation' => 
     array (
       'pretty_version' => 'v5.0.7',
@@ -541,21 +465,12 @@ class InstalledVersions
     ),
     'symfony/mime' => 
     array (
-      'pretty_version' => 'v5.4.14',
-      'version' => '5.4.14.0',
+      'pretty_version' => 'v5.4.21',
+      'version' => '5.4.21.0',
       'aliases' => 
       array (
       ),
-      'reference' => '1c118b253bb3495d81e95a6e3ec6c2766a98a0c4',
-    ),
-    'symfony/options-resolver' => 
-    array (
-      'pretty_version' => 'v5.4.11',
-      'version' => '5.4.11.0',
-      'aliases' => 
-      array (
-      ),
-      'reference' => '54f14e36aa73cb8f7261d7686691fd4d75ea2690',
+      'reference' => 'ef57d9fb9cdd5e6b2ffc567d109865d10b6920cd',
     ),
     'symfony/polyfill-ctype' => 
     array (
@@ -620,14 +535,23 @@ class InstalledVersions
       ),
       'reference' => '7a6ff3f1959bb01aefccb463a0f2cd3d3d2fd936',
     ),
-    'symfony/process' => 
+    'symfony/polyfill-php81' => 
     array (
-      'pretty_version' => 'v5.4.11',
-      'version' => '5.4.11.0',
+      'pretty_version' => 'v1.27.0',
+      'version' => '1.27.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => '6e75fe6874cbc7e4773d049616ab450eff537bf1',
+      'reference' => '707403074c8ea6e2edaf8794b0157a0bfa52157a',
+    ),
+    'symfony/process' => 
+    array (
+      'pretty_version' => 'v5.4.21',
+      'version' => '5.4.21.0',
+      'aliases' => 
+      array (
+      ),
+      'reference' => 'd4ce417ebcb0b7d090b4c178ed6d3accc518e8bd',
     ),
     'symfony/psr-http-message-bridge' => 
     array (
@@ -638,14 +562,23 @@ class InstalledVersions
       ),
       'reference' => '9d3e80d54d9ae747ad573cad796e8e247df7b796',
     ),
-    'symfony/translation' => 
+    'symfony/service-contracts' => 
     array (
-      'pretty_version' => 'v5.4.14',
-      'version' => '5.4.14.0',
+      'pretty_version' => 'v2.5.2',
+      'version' => '2.5.2.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'f0ed07675863aa6e3939df8b1bc879450b585cab',
+      'reference' => '4b426aac47d6427cc1a1d0f7e2ac724627f5966c',
+    ),
+    'symfony/translation' => 
+    array (
+      'pretty_version' => 'v5.4.21',
+      'version' => '5.4.21.0',
+      'aliases' => 
+      array (
+      ),
+      'reference' => '6996affeea65705086939894b77110e9a7f80874',
     ),
     'symfony/translation-contracts' => 
     array (
@@ -773,12 +706,12 @@ class InstalledVersions
     ),
     'webklex/php-imap' => 
     array (
-      'pretty_version' => '4.1.0',
-      'version' => '4.1.0.0',
+      'pretty_version' => '4.1.2',
+      'version' => '4.1.2.0',
       'aliases' => 
       array (
       ),
-      'reference' => '45843e1554cc280c738278b9e3b6af35a91f8b1f',
+      'reference' => '94bf93ae8868ac1e073cfbaef377f0ca1acac2bc',
     ),
   ),
 );
