@@ -30,7 +30,7 @@
  * <?php
  *    include 'vendor/autoload.php';
  *
- *    $rijndael = new \phpseclib3\Crypt\Rijndael();
+ *    $rijndael = new \phpseclib3\Crypt\Rijndael('ctr');
  *
  *    $rijndael->setKey('abcdefghijklmnop');
  *
@@ -44,8 +44,6 @@
  * ?>
  * </code>
  *
- * @category  Crypt
- * @package   Rijndael
  * @author    Jim Wigginton <terrafrost@php.net>
  * @copyright 2008 Jim Wigginton
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
@@ -54,19 +52,17 @@
 
 namespace phpseclib3\Crypt;
 
-use phpseclib3\Crypt\Common\BlockCipher;
-
 use phpseclib3\Common\Functions\Strings;
-use phpseclib3\Exception\BadModeException;
-use phpseclib3\Exception\InsufficientSetupException;
+use phpseclib3\Crypt\Common\BlockCipher;
 use phpseclib3\Exception\BadDecryptionException;
+use phpseclib3\Exception\BadModeException;
+use phpseclib3\Exception\InconsistentSetupException;
+use phpseclib3\Exception\InsufficientSetupException;
 
 /**
  * Pure-PHP implementation of Rijndael.
  *
- * @package Rijndael
  * @author  Jim Wigginton <terrafrost@php.net>
- * @access  public
  */
 class Rijndael extends BlockCipher
 {
@@ -82,7 +78,6 @@ class Rijndael extends BlockCipher
      * @see \phpseclib3\Crypt\Common\SymmetricKey::engine
      * @see self::isValidEngine()
      * @var string
-     * @access private
      */
     protected $cipher_name_mcrypt = 'rijndael-128';
 
@@ -91,7 +86,6 @@ class Rijndael extends BlockCipher
      *
      * @see self::setup()
      * @var array
-     * @access private
      */
     private $w;
 
@@ -100,7 +94,6 @@ class Rijndael extends BlockCipher
      *
      * @see self::setup()
      * @var array
-     * @access private
      */
     private $dw;
 
@@ -114,7 +107,6 @@ class Rijndael extends BlockCipher
      *
      * @see self::setBlockLength()
      * @var int
-     * @access private
      */
     private $Nb = 4;
 
@@ -128,7 +120,6 @@ class Rijndael extends BlockCipher
      *
      * @see self::setKeyLength()
      * @var int
-     * @access private
      */
     protected $key_length = 16;
 
@@ -137,7 +128,6 @@ class Rijndael extends BlockCipher
      *
      * @see self::setKeyLength()
      * @var int
-     * @access private
      * @internal The max value is 256 / 32 = 8, the min value is 128 / 32 = 4
      */
     private $Nk = 4;
@@ -148,7 +138,6 @@ class Rijndael extends BlockCipher
      * {@internal The max value is 14, the min value is 10.}
      *
      * @var int
-     * @access private
      */
     private $Nr;
 
@@ -156,7 +145,6 @@ class Rijndael extends BlockCipher
      * Shift offsets
      *
      * @var array
-     * @access private
      */
     private $c;
 
@@ -164,7 +152,6 @@ class Rijndael extends BlockCipher
      * Holds the last used key- and block_size information
      *
      * @var array
-     * @access private
      */
     private $kl;
 
@@ -172,7 +159,6 @@ class Rijndael extends BlockCipher
      * Default Constructor.
      *
      * @param string $mode
-     * @access public
      * @throws \InvalidArgumentException if an invalid / unsupported mode is provided
      */
     public function __construct($mode)
@@ -200,7 +186,6 @@ class Rijndael extends BlockCipher
      *             the mcrypt php extension, even if available.
      *             This results then in slower encryption.
      *
-     * @access public
      * @throws \LengthException if the key length is invalid
      * @param int $length
      */
@@ -227,7 +212,6 @@ class Rijndael extends BlockCipher
      * Rijndael supports five different key lengths
      *
      * @see setKeyLength()
-     * @access public
      * @param string $key
      * @throws \LengthException if the key length isn't supported
      */
@@ -252,7 +236,6 @@ class Rijndael extends BlockCipher
      *
      * Valid block lengths are 128, 160, 192, 224, and 256.
      *
-     * @access public
      * @param int $length
      */
     public function setBlockLength($length)
@@ -281,7 +264,6 @@ class Rijndael extends BlockCipher
      *
      * @see \phpseclib3\Crypt\Common\SymmetricKey::__construct()
      * @param int $engine
-     * @access protected
      * @return bool
      */
     protected function isValidEngineHelper($engine)
@@ -307,7 +289,7 @@ class Rijndael extends BlockCipher
                 if ($this->block_size != 16) {
                     return false;
                 }
-                self::$cipher_name_openssl_ecb = 'aes-' . ($this->key_length << 3) . '-ecb';
+                $this->cipher_name_openssl_ecb = 'aes-' . ($this->key_length << 3) . '-ecb';
                 $this->cipher_name_openssl = 'aes-' . ($this->key_length << 3) . '-' . $this->openssl_translate_mode();
                 break;
             case self::ENGINE_MCRYPT:
@@ -324,7 +306,6 @@ class Rijndael extends BlockCipher
     /**
      * Encrypts a block
      *
-     * @access private
      * @param string $in
      * @return string
      */
@@ -397,7 +378,7 @@ class Rijndael extends BlockCipher
         $k = $c[2];
         $l = $c[3];
         while ($i < $Nb) {
-            $temp[$i] = ($state[$i] & 0xFF000000) ^
+            $temp[$i] = ($state[$i] & intval(0xFF000000)) ^
                         ($state[$j] & 0x00FF0000) ^
                         ($state[$k] & 0x0000FF00) ^
                         ($state[$l] & 0x000000FF) ^
@@ -414,7 +395,6 @@ class Rijndael extends BlockCipher
     /**
      * Decrypts a block
      *
-     * @access private
      * @param string $in
      * @return string
      */
@@ -472,7 +452,7 @@ class Rijndael extends BlockCipher
         $l = $Nb - $c[3];
 
         while ($i < $Nb) {
-            $word = ($state[$i] & 0xFF000000) |
+            $word = ($state[$i] & intval(0xFF000000)) |
                     ($state[$j] & 0x00FF0000) |
                     ($state[$k] & 0x0000FF00) |
                     ($state[$l] & 0x000000FF);
@@ -490,24 +470,66 @@ class Rijndael extends BlockCipher
         return pack('N*', ...$temp);
     }
 
+    /**
+     * Setup the self::ENGINE_INTERNAL $engine
+     *
+     * (re)init, if necessary, the internal cipher $engine and flush all $buffers
+     * Used (only) if $engine == self::ENGINE_INTERNAL
+     *
+     * _setup() will be called each time if $changed === true
+     * typically this happens when using one or more of following public methods:
+     *
+     * - setKey()
+     *
+     * - setIV()
+     *
+     * - disableContinuousBuffer()
+     *
+     * - First run of encrypt() / decrypt() with no init-settings
+     *
+     * {@internal setup() is always called before en/decryption.}
+     *
+     * {@internal Could, but not must, extend by the child Crypt_* class}
+     *
+     * @see self::setKey()
+     * @see self::setIV()
+     * @see self::disableContinuousBuffer()
+     */
+    protected function setup()
+    {
+        if (!$this->changed) {
+            return;
+        }
+
+        parent::setup();
+
+        if (is_string($this->iv) && strlen($this->iv) != $this->block_size) {
+            throw new InconsistentSetupException('The IV length (' . strlen($this->iv) . ') does not match the block size (' . $this->block_size . ')');
+        }
+    }
+
     /**
      * Setup the key (expansion)
      *
      * @see \phpseclib3\Crypt\Common\SymmetricKey::setupKey()
-     * @access private
      */
     protected function setupKey()
     {
         // Each number in $rcon is equal to the previous number multiplied by two in Rijndael's finite field.
         // See http://en.wikipedia.org/wiki/Finite_field_arithmetic#Multiplicative_inverse
-        static $rcon = [0,
-            0x01000000, 0x02000000, 0x04000000, 0x08000000, 0x10000000,
-            0x20000000, 0x40000000, 0x80000000, 0x1B000000, 0x36000000,
-            0x6C000000, 0xD8000000, 0xAB000000, 0x4D000000, 0x9A000000,
-            0x2F000000, 0x5E000000, 0xBC000000, 0x63000000, 0xC6000000,
-            0x97000000, 0x35000000, 0x6A000000, 0xD4000000, 0xB3000000,
-            0x7D000000, 0xFA000000, 0xEF000000, 0xC5000000, 0x91000000
-        ];
+        static $rcon;
+
+        if (!isset($rcon)) {
+            $rcon = [0,
+                0x01000000, 0x02000000, 0x04000000, 0x08000000, 0x10000000,
+                0x20000000, 0x40000000, 0x80000000, 0x1B000000, 0x36000000,
+                0x6C000000, 0xD8000000, 0xAB000000, 0x4D000000, 0x9A000000,
+                0x2F000000, 0x5E000000, 0xBC000000, 0x63000000, 0xC6000000,
+                0x97000000, 0x35000000, 0x6A000000, 0xD4000000, 0xB3000000,
+                0x7D000000, 0xFA000000, 0xEF000000, 0xC5000000, 0x91000000
+            ];
+            $rcon = array_map('intval', $rcon);
+        }
 
         if (isset($this->kl['key']) && $this->key === $this->kl['key'] && $this->key_length === $this->kl['key_length'] && $this->block_size === $this->kl['block_size']) {
             // already expanded
@@ -546,7 +568,7 @@ class Rijndael extends BlockCipher
                 // on a 32-bit machine, it's 32-bits, and on a 64-bit machine, it's 64-bits. on a 32-bit machine,
                 // 0xFFFFFFFF << 8 == 0xFFFFFF00, but on a 64-bit machine, it equals 0xFFFFFFFF00. as such, doing 'and'
                 // with 0xFFFFFFFF (or 0xFFFFFF00) on a 32-bit machine is unnecessary, but on a 64-bit machine, it is.
-                $temp = (($temp << 8) & 0xFFFFFF00) | (($temp >> 24) & 0x000000FF); // rotWord
+                $temp = (($temp << 8) & intval(0xFFFFFF00)) | (($temp >> 24) & 0x000000FF); // rotWord
                 $temp = $this->subWord($temp) ^ $rcon[$i / $this->Nk];
             } elseif ($this->Nk > 6 && $i % $this->Nk == 4) {
                 $temp = $this->subWord($temp);
@@ -607,7 +629,6 @@ class Rijndael extends BlockCipher
      * Performs S-Box substitutions
      *
      * @return array
-     * @access private
      * @param int $word
      */
     private function subWord($word)
@@ -629,7 +650,6 @@ class Rijndael extends BlockCipher
      * @see self::encryptBlock()
      * @see self::setupInlineCrypt()
      * @see self::subWord()
-     * @access private
      * @return array &$tables
      */
     protected function &getTables()
@@ -677,9 +697,9 @@ class Rijndael extends BlockCipher
             ]);
 
             foreach ($t3 as $t3i) {
-                $t0[] = (($t3i << 24) & 0xFF000000) | (($t3i >>  8) & 0x00FFFFFF);
-                $t1[] = (($t3i << 16) & 0xFFFF0000) | (($t3i >> 16) & 0x0000FFFF);
-                $t2[] = (($t3i <<  8) & 0xFFFFFF00) | (($t3i >> 24) & 0x000000FF);
+                $t0[] = (($t3i << 24) & intval(0xFF000000)) | (($t3i >>  8) & 0x00FFFFFF);
+                $t1[] = (($t3i << 16) & intval(0xFFFF0000)) | (($t3i >> 16) & 0x0000FFFF);
+                $t2[] = (($t3i <<  8) & intval(0xFFFFFF00)) | (($t3i >> 24) & 0x000000FF);
             }
 
             $tables = [
@@ -718,7 +738,6 @@ class Rijndael extends BlockCipher
      * @see self::decryptBlock()
      * @see self::setupInlineCrypt()
      * @see self::setupKey()
-     * @access private
      * @return array &$tables
      */
     protected function &getInvTables()
@@ -761,9 +780,9 @@ class Rijndael extends BlockCipher
             ]);
 
             foreach ($dt3 as $dt3i) {
-                $dt0[] = (($dt3i << 24) & 0xFF000000) | (($dt3i >>  8) & 0x00FFFFFF);
-                $dt1[] = (($dt3i << 16) & 0xFFFF0000) | (($dt3i >> 16) & 0x0000FFFF);
-                $dt2[] = (($dt3i <<  8) & 0xFFFFFF00) | (($dt3i >> 24) & 0x000000FF);
+                $dt0[] = (($dt3i << 24) & intval(0xFF000000)) | (($dt3i >>  8) & 0x00FFFFFF);
+                $dt1[] = (($dt3i << 16) & intval(0xFFFF0000)) | (($dt3i >> 16) & 0x0000FFFF);
+                $dt2[] = (($dt3i <<  8) & intval(0xFFFFFF00)) | (($dt3i >> 24) & 0x000000FF);
             };
 
             $tables = [
@@ -800,7 +819,6 @@ class Rijndael extends BlockCipher
      * Setup the performance-optimized function for de/encrypt()
      *
      * @see \phpseclib3\Crypt\Common\SymmetricKey::setupInlineCrypt()
-     * @access private
      */
     protected function setupInlineCrypt()
     {
@@ -814,7 +832,7 @@ class Rijndael extends BlockCipher
         $c  = $this->c;
 
         // Generating encrypt code:
-        $init_encrypt.= '
+        $init_encrypt .= '
             static $tables;
             if (empty($tables)) {
                 $tables = &$this->getTables();
@@ -831,47 +849,47 @@ class Rijndael extends BlockCipher
         $wc = $Nb - 1;
 
         // Preround: addRoundKey
-        $encrypt_block = '$in = unpack("N*", $in);'."\n";
+        $encrypt_block = '$in = unpack("N*", $in);' . "\n";
         for ($i = 0; $i < $Nb; ++$i) {
-            $encrypt_block .= '$s'.$i.' = $in['.($i + 1).'] ^ '.$w[++$wc].";\n";
+            $encrypt_block .= '$s' . $i . ' = $in[' . ($i + 1) . '] ^ ' . $w[++$wc] . ";\n";
         }
 
         // Mainrounds: shiftRows + subWord + mixColumns + addRoundKey
         for ($round = 1; $round < $Nr; ++$round) {
             list($s, $e) = [$e, $s];
             for ($i = 0; $i < $Nb; ++$i) {
-                $encrypt_block.=
-                    '$'.$e.$i.' =
-                    $t0[($'.$s.$i                  .' >> 24) & 0xff] ^
-                    $t1[($'.$s.(($i + $c[1]) % $Nb).' >> 16) & 0xff] ^
-                    $t2[($'.$s.(($i + $c[2]) % $Nb).' >>  8) & 0xff] ^
-                    $t3[ $'.$s.(($i + $c[3]) % $Nb).'        & 0xff] ^
-                    '.$w[++$wc].";\n";
+                $encrypt_block .=
+                    '$' . $e . $i . ' =
+                    $t0[($' . $s . $i                  . ' >> 24) & 0xff] ^
+                    $t1[($' . $s . (($i + $c[1]) % $Nb) . ' >> 16) & 0xff] ^
+                    $t2[($' . $s . (($i + $c[2]) % $Nb) . ' >>  8) & 0xff] ^
+                    $t3[ $' . $s . (($i + $c[3]) % $Nb) . '        & 0xff] ^
+                    ' . $w[++$wc] . ";\n";
             }
         }
 
         // Finalround: subWord + shiftRows + addRoundKey
         for ($i = 0; $i < $Nb; ++$i) {
-            $encrypt_block.=
-                '$'.$e.$i.' =
-                 $sbox[ $'.$e.$i.'        & 0xff]        |
-                ($sbox[($'.$e.$i.' >>  8) & 0xff] <<  8) |
-                ($sbox[($'.$e.$i.' >> 16) & 0xff] << 16) |
-                ($sbox[($'.$e.$i.' >> 24) & 0xff] << 24);'."\n";
+            $encrypt_block .=
+                '$' . $e . $i . ' =
+                 $sbox[ $' . $e . $i . '        & 0xff]        |
+                ($sbox[($' . $e . $i . ' >>  8) & 0xff] <<  8) |
+                ($sbox[($' . $e . $i . ' >> 16) & 0xff] << 16) |
+                ($sbox[($' . $e . $i . ' >> 24) & 0xff] << 24);' . "\n";
         }
-        $encrypt_block .= '$in = pack("N*"'."\n";
+        $encrypt_block .= '$in = pack("N*"' . "\n";
         for ($i = 0; $i < $Nb; ++$i) {
-            $encrypt_block.= ',
-                ($'.$e.$i                  .' & '.((int)0xFF000000).') ^
-                ($'.$e.(($i + $c[1]) % $Nb).' &         0x00FF0000   ) ^
-                ($'.$e.(($i + $c[2]) % $Nb).' &         0x0000FF00   ) ^
-                ($'.$e.(($i + $c[3]) % $Nb).' &         0x000000FF   ) ^
-                '.$w[$i]."\n";
+            $encrypt_block .= ',
+                ($' . $e . $i                  . ' & ' . ((int)0xFF000000) . ') ^
+                ($' . $e . (($i + $c[1]) % $Nb) . ' &         0x00FF0000   ) ^
+                ($' . $e . (($i + $c[2]) % $Nb) . ' &         0x0000FF00   ) ^
+                ($' . $e . (($i + $c[3]) % $Nb) . ' &         0x000000FF   ) ^
+                ' . $w[$i] . "\n";
         }
         $encrypt_block .= ');';
 
         // Generating decrypt code:
-        $init_decrypt.= '
+        $init_decrypt .= '
             static $invtables;
             if (empty($invtables)) {
                 $invtables = &$this->getInvTables();
@@ -888,42 +906,42 @@ class Rijndael extends BlockCipher
         $wc = $Nb - 1;
 
         // Preround: addRoundKey
-        $decrypt_block = '$in = unpack("N*", $in);'."\n";
+        $decrypt_block = '$in = unpack("N*", $in);' . "\n";
         for ($i = 0; $i < $Nb; ++$i) {
-            $decrypt_block .= '$s'.$i.' = $in['.($i + 1).'] ^ '.$dw[++$wc].';'."\n";
+            $decrypt_block .= '$s' . $i . ' = $in[' . ($i + 1) . '] ^ ' . $dw[++$wc] . ';' . "\n";
         }
 
         // Mainrounds: shiftRows + subWord + mixColumns + addRoundKey
         for ($round = 1; $round < $Nr; ++$round) {
             list($s, $e) = [$e, $s];
             for ($i = 0; $i < $Nb; ++$i) {
-                $decrypt_block.=
-                    '$'.$e.$i.' =
-                    $dt0[($'.$s.$i                        .' >> 24) & 0xff] ^
-                    $dt1[($'.$s.(($Nb + $i - $c[1]) % $Nb).' >> 16) & 0xff] ^
-                    $dt2[($'.$s.(($Nb + $i - $c[2]) % $Nb).' >>  8) & 0xff] ^
-                    $dt3[ $'.$s.(($Nb + $i - $c[3]) % $Nb).'        & 0xff] ^
-                    '.$dw[++$wc].";\n";
+                $decrypt_block .=
+                    '$' . $e . $i . ' =
+                    $dt0[($' . $s . $i                        . ' >> 24) & 0xff] ^
+                    $dt1[($' . $s . (($Nb + $i - $c[1]) % $Nb) . ' >> 16) & 0xff] ^
+                    $dt2[($' . $s . (($Nb + $i - $c[2]) % $Nb) . ' >>  8) & 0xff] ^
+                    $dt3[ $' . $s . (($Nb + $i - $c[3]) % $Nb) . '        & 0xff] ^
+                    ' . $dw[++$wc] . ";\n";
             }
         }
 
         // Finalround: subWord + shiftRows + addRoundKey
         for ($i = 0; $i < $Nb; ++$i) {
-            $decrypt_block.=
-                '$'.$e.$i.' =
-                 $isbox[ $'.$e.$i.'        & 0xff]        |
-                ($isbox[($'.$e.$i.' >>  8) & 0xff] <<  8) |
-                ($isbox[($'.$e.$i.' >> 16) & 0xff] << 16) |
-                ($isbox[($'.$e.$i.' >> 24) & 0xff] << 24);'."\n";
+            $decrypt_block .=
+                '$' . $e . $i . ' =
+                 $isbox[ $' . $e . $i . '        & 0xff]        |
+                ($isbox[($' . $e . $i . ' >>  8) & 0xff] <<  8) |
+                ($isbox[($' . $e . $i . ' >> 16) & 0xff] << 16) |
+                ($isbox[($' . $e . $i . ' >> 24) & 0xff] << 24);' . "\n";
         }
-        $decrypt_block .= '$in = pack("N*"'."\n";
+        $decrypt_block .= '$in = pack("N*"' . "\n";
         for ($i = 0; $i < $Nb; ++$i) {
-            $decrypt_block.= ',
-                ($'.$e.$i.                        ' & '.((int)0xFF000000).') ^
-                ($'.$e.(($Nb + $i - $c[1]) % $Nb).' &         0x00FF0000   ) ^
-                ($'.$e.(($Nb + $i - $c[2]) % $Nb).' &         0x0000FF00   ) ^
-                ($'.$e.(($Nb + $i - $c[3]) % $Nb).' &         0x000000FF   ) ^
-                '.$dw[$i]."\n";
+            $decrypt_block .= ',
+                ($' . $e . $i .                        ' & ' . ((int)0xFF000000) . ') ^
+                ($' . $e . (($Nb + $i - $c[1]) % $Nb) . ' &         0x00FF0000   ) ^
+                ($' . $e . (($Nb + $i - $c[2]) % $Nb) . ' &         0x0000FF00   ) ^
+                ($' . $e . (($Nb + $i - $c[3]) % $Nb) . ' &         0x000000FF   ) ^
+                ' . $dw[$i] . "\n";
         }
         $decrypt_block .= ');';
 
@@ -943,7 +961,6 @@ class Rijndael extends BlockCipher
      *
      * @see self::decrypt()
      * @see parent::encrypt()
-     * @access public
      * @param string $plaintext
      * @return string
      */
@@ -975,7 +992,6 @@ class Rijndael extends BlockCipher
      *
      * @see self::encrypt()
      * @see parent::decrypt()
-     * @access public
      * @param string $ciphertext
      * @return string
      */
