@@ -5,7 +5,7 @@ declare(strict_types=1);
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2018 Spomky-Labs
+ * Copyright (c) 2018-2020 Spomky-Labs
  *
  * This software may be modified and distributed under the terms
  * of the MIT license.  See the LICENSE file for details.
@@ -13,17 +13,26 @@ declare(strict_types=1);
 
 namespace CBOR\OtherObject;
 
+use function array_key_exists;
 use CBOR\OtherObject;
 use InvalidArgumentException;
 
-class OtherObjectManager
+/**
+ * @final
+ */
+class OtherObjectManager implements OtherObjectManagerInterface
 {
     /**
      * @var string[]
      */
     private $classes = [];
 
-    public function add(string $class): void
+    public static function create(): self
+    {
+        return new self();
+    }
+
+    public function add(string $class): self
     {
         foreach ($class::supportedAdditionalInformation() as $ai) {
             if ($ai < 0) {
@@ -31,11 +40,13 @@ class OtherObjectManager
             }
             $this->classes[$ai] = $class;
         }
+
+        return $this;
     }
 
     public function getClassForValue(int $value): string
     {
-        return \array_key_exists($value, $this->classes) ? $this->classes[$value] : GenericObject::class;
+        return array_key_exists($value, $this->classes) ? $this->classes[$value] : GenericObject::class;
     }
 
     public function createObjectForValue(int $value, ?string $data): OtherObject
