@@ -11,7 +11,7 @@ use htmlStatusMessage;
 /*
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2020 - 2021  Roland Gruber
+  Copyright (C) 2020 - 2022  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -114,7 +114,7 @@ printContent($message);
  * @param htmlStatusMessage $message status message
  * @param bool $showPasswordInputs show password input fields
  */
-function printContent($message = null, $showPasswordInputs = true) {
+function printContent($message = null, $showPasswordInputs = true): void {
 	include __DIR__ . '/../lib/adminHeader.inc';
 	echo '<div class="smallPaddingContent">';
 	echo "<form action=\"changePassword.php\" method=\"post\">\n";
