@@ -49,7 +49,7 @@ include_once '../../lib/types.inc';
 include_once '../../lib/configPages.inc';
 
 // start session
-if (strtolower(session_module_name()) == 'files') {
+if (isFileBasedSession()) {
 	session_save_path("../../sess");
 }
 lam_start_session();
@@ -147,7 +147,7 @@ for ($i = 0; $i < sizeof($errorsToDisplay); $i++) {
 	call_user_func_array('StatusMessage', $errorsToDisplay[$i]);
 }
 
-echo "<form action=\"conftypes.php\" method=\"post\">\n";
+echo "<form action=\"conftypes.php\" method=\"post\" novalidate=\"novalidate\">\n";
 
 printConfigurationPageTabs(ConfigurationPageTab::TYPES);
 
