@@ -1,6 +1,7 @@
 <?php
 namespace LAM\CONFIG;
 
+use htmlJavaScript;
 use htmlResponsiveTable;
 use LAM\LOGIN\WEBAUTHN\WebauthnManager;
 use \LAMCfgMain;
@@ -31,7 +32,7 @@ use PDO;
 /*
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2022  Roland Gruber
+  Copyright (C) 2003 - 2023  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -91,6 +92,43 @@ if (isset($_POST['cancel'])) {
 	exit();
 }
 
+if (isset($_SESSION['header'])) {
+	echo $_SESSION['header'];
+}
+printHeaderContents(_("Edit general settings"), '../..');
+?>
+</head>
+<body>
+<div id="lam-topnav" class="lam-header">
+    <div class="lam-header-left lam-menu-stay">
+        <a href="https://www.ldap-account-manager.org/" target="new_window">
+            <img class="align-middle" width="24" height="24" alt="help" src="../../graphics/logo24.png">
+            <span class="hide-on-mobile">
+                        <?php
+						echo getLAMVersionText();
+						?>
+                    </span>
+        </a>
+    </div>
+	<?php
+	if (is_dir(dirname(__FILE__) . '/../../docs/manual')) {
+		?>
+        <a class="lam-header-right lam-menu-icon hide-on-tablet" href="javascript:void(0);" class="icon" onclick="window.lam.topmenu.toggle();">
+            <img class="align-middle" width="16" height="16" alt="menu" src="../../graphics/menu.svg">
+            <span class="padding0">&nbsp;</span>
+        </a>
+        <a class="lam-header-right lam-menu-entry" target="_blank" href="../../docs/manual/index.html">
+            <span class="padding0"><?php echo _("Help") ?></span>
+        </a>
+		<?php
+	}
+	?>
+</div>
+<br>
+<?php
+// include all JavaScript files
+printJsIncludes('../..');
+
 $errors = array();
 $messages = array();
 // check if submit button was pressed
@@ -154,6 +192,8 @@ if (isset($_POST['submitFormData'])) {
 	}
 	// set session timeout
 	$cfg->sessionTimeout = $_POST['sessionTimeout'];
+	// set hide login error details
+	$cfg->hideLoginErrorDetails = (isset($_POST['hideLoginErrorDetails']) && ($_POST['hideLoginErrorDetails'] === 'on')) ? 'true' : 'false';
 	// set allowed hosts
 	if (isset($_POST['allowedHosts'])) {
 		$allowedHosts = $_POST['allowedHosts'];
@@ -308,52 +348,19 @@ if (isset($_POST['submitFormData'])) {
 	if (isset($_POST['submit'])) {
 		$cfg->save();
 		if (sizeof($errors) == 0) {
-			metaRefresh('../login.php?confMainSavedOk=1');
+			$scriptTag = new htmlJavaScript('window.lam.dialog.showSuccessMessageAndRedirect("' . _("Your settings were successfully saved.") . '", "", "' . _('Ok') . '", "../login.php")');
+			$tabIndex = 0;
+			parseHtml(null, $scriptTag, array(), false, $tabIndex, null);
+			echo '</body></html>';
 			exit();
 		}
 	}
 }
 
-if (isset($_SESSION['header'])) {
-	echo $_SESSION['header'];
-}
-printHeaderContents(_("Edit general settings"), '../..');
 ?>
-</head>
-<body>
-<div id="lam-topnav" class="lam-header">
-    <div class="lam-header-left lam-menu-stay">
-        <a href="https://www.ldap-account-manager.org/" target="new_window">
-            <img class="align-middle" width="24" height="24" alt="help" src="../../graphics/logo24.png">
-            <span class="hide-on-mobile">
-                        <?php
-                        echo getLAMVersionText();
-                        ?>
-                    </span>
-        </a>
-    </div>
-	<?php
-	if (is_dir(dirname(__FILE__) . '/../../docs/manual')) {
-		?>
-        <a class="lam-header-right lam-menu-icon hide-on-tablet" href="javascript:void(0);" class="icon" onclick="window.lam.topmenu.toggle();">
-            <img class="align-middle" width="16" height="16" alt="menu" src="../../graphics/menu.svg">
-            <span class="padding0">&nbsp;</span>
-        </a>
-        <a class="lam-header-right lam-menu-entry" target="_blank" href="../../docs/manual/index.html">
-            <span class="padding0"><?php echo _("Help") ?></span>
-        </a>
-		<?php
-	}
-	?>
-</div>
-<br>
-<!-- form for adding/renaming/deleting profiles -->
-<form enctype="multipart/form-data" action="mainmanage.php" method="post" novalidate="novalidate">
+<form class="text-center" enctype="multipart/form-data" action="mainmanage.php" method="post" novalidate="novalidate">
 
 	<?php
-	// include all JavaScript files
-	printJsIncludes('../..');
-
 	$tabindex = 1;
 
 	$row = new htmlResponsiveRow();
@@ -446,10 +453,12 @@ printHeaderContents(_("Edit general settings"), '../..');
 	// security settings
 	$row->add(new htmlSubTitle(_("Security settings")), 12);
 	$options = array(5, 10, 20, 30, 60, 90, 120, 240);
-	$row->add(new htmlResponsiveSelect('sessionTimeout', $options, array($cfg->sessionTimeout), _("Session timeout"), '238'), 12);
-	$row->add(new htmlResponsiveInputTextarea('allowedHosts', implode("\n", explode(",", $cfg->allowedHosts)), '30', '7', _("Allowed hosts"), '241'), 12);
+	$row->add(new htmlResponsiveSelect('sessionTimeout', $options, array($cfg->sessionTimeout), _("Session timeout"), '238'));
+	$hideLoginErrorDetails = ($cfg->hideLoginErrorDetails === 'true');
+	$row->add(new htmlResponsiveInputCheckbox('hideLoginErrorDetails', $hideLoginErrorDetails, _('Hide LDAP details on failed login'), '257'));
+	$row->add(new htmlResponsiveInputTextarea('allowedHosts', implode("\n", explode(",", $cfg->allowedHosts)), '30', '7', _("Allowed hosts"), '241'));
 	if (isLAMProVersion()) {
-		$row->add(new htmlResponsiveInputTextarea('allowedHostsSelfService', implode("\n", explode(",", $cfg->allowedHostsSelfService)), '30', '7', _("Allowed hosts (self service)"), '241'), 12);
+		$row->add(new htmlResponsiveInputTextarea('allowedHostsSelfService', implode("\n", explode(",", $cfg->allowedHostsSelfService)), '30', '7', _("Allowed hosts (self service)"), '241'));
 	}
 	// SSL certificate
 	$row->addVerticalSpacer('1rem');
@@ -511,6 +520,7 @@ printHeaderContents(_("Edit general settings"), '../..');
 			);
 		}
 		$certsTable = new htmlResponsiveTable($certsTitles, $certsData);
+		$certsTable->setCSSClasses(array('text-left'));
 		$row->add($certsTable, 12);
 	}
 
@@ -628,7 +638,7 @@ printHeaderContents(_("Edit general settings"), '../..');
 				$row->add($webauthnSearchField, 12);
 				$row->addVerticalSpacer('0.5rem');
 				$row->add(new htmlButton('webauthn_search', _('Search')), 12, 12, 12, 'text-center');
-				$resultDiv = new htmlDiv('webauthn_results', new htmlOutputText(''), array('lam-webauthn-results'));
+				$resultDiv = new htmlDiv('webauthn_results', new htmlOutputText(''), array('lam-webauthn-results', 'text-left'));
 				addSecurityTokenToSession(false);
 				$resultDiv->addDataAttribute('sec_token_value', getSecurityTokenValue());
 				$row->add($resultDiv, 12);
@@ -666,7 +676,7 @@ printHeaderContents(_("Edit general settings"), '../..');
 	}
 
 	$box = new htmlDiv(null, $row);
-	$box->setCSSClasses(array('ui-corner-all', 'roundedShadowBox'));
+	$box->setCSSClasses(array('roundedShadowBox'));
 	parseHtml(null, $box, array(), false, $tabindex, 'user');
 
 
