@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -150,7 +150,7 @@ CKEDITOR.htmlParser.cssStyle = function() {
 		/**
 		 * Filters this element and its children with the given filter.
 		 *
-		 * @since 4.1
+		 * @since 4.1.0
 		 * @param {CKEDITOR.htmlParser.filter} filter
 		 * @returns {Boolean} The method returns `false` when this element has
 		 * been removed or replaced with another. This information means that
@@ -163,10 +163,6 @@ CKEDITOR.htmlParser.cssStyle = function() {
 
 			context = element.getFilterContext( context );
 
-			// Do not process elements with data-cke-processor attribute set to off.
-			if ( context.off )
-				return true;
-
 			// Filtering if it's the root node.
 			if ( !element.parent )
 				filter.onRoot( context, element );
@@ -319,7 +315,7 @@ CKEDITOR.htmlParser.cssStyle = function() {
 		/**
 		 * Replaces this element with its children.
 		 *
-		 * @since 4.1
+		 * @since 4.1.0
 		 */
 		replaceWithChildren: function() {
 			var children = this.children;
@@ -346,7 +342,7 @@ CKEDITOR.htmlParser.cssStyle = function() {
 		 *		// 5. "bar" text node,
 		 *		// 6. "bom" text node.
 		 *
-		 * @since 4.1
+		 * @since 4.1.0
 		 * @param {Function} callback Function to be executed on every node.
 		 * **Since 4.3**: If `callback` returned `false`, the descendants of the current node will be ignored.
 		 * @param {CKEDITOR.htmlParser.node} callback.node Node passed as an argument.
@@ -359,7 +355,7 @@ CKEDITOR.htmlParser.cssStyle = function() {
 		 * Gets this element's first child. If `condition` is given, this method returns
 		 * the first child which satisfies that condition.
 		 *
-		 * @since 4.3
+		 * @since 4.3.0
 		 * @param {String/Object/Function} condition Name of a child, a hash of names, or a validator function.
 		 * @returns {CKEDITOR.htmlParser.node}
 		 */
@@ -380,7 +376,7 @@ CKEDITOR.htmlParser.cssStyle = function() {
 		/**
 		 * Gets this element's inner HTML.
 		 *
-		 * @since 4.3
+		 * @since 4.3.0
 		 * @returns {String}
 		 */
 		getHtml: function() {
@@ -392,7 +388,7 @@ CKEDITOR.htmlParser.cssStyle = function() {
 		/**
 		 * Sets this element's inner HTML.
 		 *
-		 * @since 4.3
+		 * @since 4.3.0
 		 * @param {String} html
 		 */
 		setHtml: function( html ) {
@@ -405,7 +401,7 @@ CKEDITOR.htmlParser.cssStyle = function() {
 		/**
 		 * Gets this element's outer HTML.
 		 *
-		 * @since 4.3
+		 * @since 4.3.0
 		 * @returns {String}
 		 */
 		getOuterHtml: function() {
@@ -417,7 +413,7 @@ CKEDITOR.htmlParser.cssStyle = function() {
 		/**
 		 * Splits this element at the given index.
 		 *
-		 * @since 4.3
+		 * @since 4.3.0
 		 * @param {Number} index Index at which the element will be split &mdash; `0` means the beginning,
 		 * `1` after the first child node, etc.
 		 * @returns {CKEDITOR.htmlParser.element} The new element following this one.
@@ -474,10 +470,43 @@ CKEDITOR.htmlParser.cssStyle = function() {
 			return ret;
 		},
 
+		/**
+		 * Searches through the children of the current element to find the first child matching the `criteria`.
+		 *
+		 * ```js
+		 * element.findOne( function( child ) {
+		 *     return child.name === 'span' || child.name === 'strong';
+		 * } ); // Will return the first child which is a <span> or a <strong> element.
+		 * ```
+		 *
+		 * @param {String/Function} criteria Tag name or evaluator function.
+		 * @param {Boolean} [recursive=false] If set to `true`, it will iterate over all descendants. Otherwise the method will
+		 * only iterate over direct children.
+		 * @returns {CKEDITOR.htmlParser.node/null} The first matched child, `null` otherwise.
+		 */
+		findOne: function( criteria, recursive ) {
+			var nestedMatch = null,
+				match = CKEDITOR.tools.array.find( this.children, function( child ) {
+					var isMatching = typeof criteria === 'function' ? criteria( child ) : child.name === criteria;
+
+					if ( isMatching || !recursive ) {
+						return isMatching;
+					}
+
+					if ( child.children && child.findOne ) {
+						nestedMatch = child.findOne( criteria, true );
+					}
+
+					return !!nestedMatch;
+				} );
+
+			return nestedMatch || match || null;
+		},
+
 		/**
 		 * Adds a class name to the list of classes.
 		 *
-		 * @since 4.4
+		 * @since 4.4.0
 		 * @param {String} className The class name to be added.
 		 */
 		addClass: function( className ) {
@@ -492,7 +521,7 @@ CKEDITOR.htmlParser.cssStyle = function() {
 		/**
 		 * Removes a class name from the list of classes.
 		 *
-		 * @since 4.3
+		 * @since 4.3.0
 		 * @param {String} className The class name to be removed.
 		 */
 		removeClass: function( className ) {
@@ -514,7 +543,7 @@ CKEDITOR.htmlParser.cssStyle = function() {
 		/**
 		 * Checkes whether this element has a class name.
 		 *
-		 * @since 4.3
+		 * @since 4.3.0
 		 * @param {String} className The class name to be checked.
 		 * @returns {Boolean} Whether this element has a `className`.
 		 */
@@ -532,15 +561,11 @@ CKEDITOR.htmlParser.cssStyle = function() {
 
 			if ( !ctx ) {
 				ctx = {
-					off: false,
 					nonEditable: false,
 					nestedEditable: false
 				};
 			}
 
-			if ( !ctx.off && this.attributes[ 'data-cke-processor' ] == 'off' )
-				changes.push( 'off', true );
-
 			if ( !ctx.nonEditable && this.attributes.contenteditable == 'false' )
 				changes.push( 'nonEditable', true );
 			// A context to be given nestedEditable must be nonEditable first (by inheritance) (https://dev.ckeditor.com/ticket/11372, https://dev.ckeditor.com/ticket/11698).
