@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -84,7 +84,7 @@ CKEDITOR.lang[ 'zh' ] = {
 		justify: '左右對齊',
 		alignLeft: '靠左對齊',
 		alignRight: '靠右對齊',
-		alignCenter: 'Align Center', // MISSING
+		alignCenter: '置中對齊',
 		alignTop: '頂端',
 		alignMiddle: '中間對齊',
 		alignBottom: '底端',
