@@ -1,12 +1,12 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'basicstyles', 'bg', {
 	bold: 'Удебелен',
 	italic: 'Наклонен',
 	strike: 'Зачертан текст',
-	subscript: 'Индексиран текст',
-	superscript: 'Суперскрипт',
+	subscript: 'Долен индекс',
+	superscript: 'Горен индекс',
 	underline: 'Подчертан'
 } );
