@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'colorbutton', 'ru', {
@@ -46,27 +46,27 @@ CKEDITOR.plugins.setLang( 'colorbutton', 'ru', {
 		F0F8FF: 'Бледно-голубой',
 		E6E6FA: 'Лавандовый',
 		FFF: 'Белый',
-		'1ABC9C': 'Strong Cyan', // MISSING
+		'1ABC9C': 'Насыщенный голубой',
 		'2ECC71': 'Изумрудный',
 		'3498DB': 'Светло-синий',
 		'9B59B6': 'Аметист',
 		'4E5F70': 'Сине-серый',
 		'F1C40F': 'Ярко-желтый',
-		'16A085': 'Dark Cyan', // MISSING
+		'16A085': 'Тёмно-голубой',
 		'27AE60': 'Тёмно-изумрудный',
-		'2980B9': 'Strong Blue', // MISSING
+		'2980B9': 'Насыщенный синий',
 		'8E44AD': 'Тёмно-фиолетовый',
-		'2C3E50': 'Desaturated Blue', // MISSING
+		'2C3E50': 'Ненасыщенный синий',
 		'F39C12': 'Оранжевый',
 		'E67E22': 'Морковный',
-		'E74C3C': 'Pale Red', // MISSING
-		'ECF0F1': 'Bright Silver', // MISSING
-		'95A5A6': 'Light Grayish Cyan', // MISSING
+		'E74C3C': 'Бледно-красный',
+		'ECF0F1': 'Яркий серебристый',
+		'95A5A6': 'Светлый серо-голубой',
 		'DDD': 'Светло-серый',
 		'D35400': 'Цвет тыквы',
-		'C0392B': 'Strong Red', // MISSING
+		'C0392B': 'Насыщенный красный',
 		'BDC3C7': 'Серебристый',
-		'7F8C8D': 'Grayish Cyan', // MISSING
+		'7F8C8D': 'Серо-голубой',
 		'999': 'Тёмно-серый'
 	},
 	more: 'Ещё цвета...',
