@@ -1,5 +1,5 @@
 ﻿/**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -30,6 +30,8 @@ CKEDITOR.plugins.add( 'contextmenu', {
 			$: function( editor ) {
 				this.base.call( this, editor, {
 					panel: {
+						// Allow adding custom CSS (#2202).
+						css: editor.config.contextmenu_contentsCss,
 						className: 'cke_menu_panel',
 						attributes: {
 							'aria-label': editor.lang.contextmenu.options
@@ -47,6 +49,9 @@ CKEDITOR.plugins.add( 'contextmenu', {
 				 * <kbd>Ctrl</kbd> key is held on opening the context menu. See {@link CKEDITOR.config#browserContextMenuOnCtrl}.
 				 */
 				addTarget: function( element, nativeContextMenuOnCtrl ) {
+					var holdCtrlKey,
+						keystrokeActive;
+
 					element.on( 'contextmenu', function( event ) {
 						var domEvent = event.data,
 							isCtrlKeyDown =
@@ -54,12 +59,18 @@ CKEDITOR.plugins.add( 'contextmenu', {
 								// which make this property unreliable. (https://dev.ckeditor.com/ticket/4826)
 								( CKEDITOR.env.webkit ? holdCtrlKey : ( CKEDITOR.env.mac ? domEvent.$.metaKey : domEvent.$.ctrlKey ) );
 
-						if ( nativeContextMenuOnCtrl && isCtrlKeyDown )
+						if ( nativeContextMenuOnCtrl && isCtrlKeyDown ) {
 							return;
+						}
 
 						// Cancel the browser context menu.
 						domEvent.preventDefault();
 
+						// Do not react to this event, as it might open context menu in wrong position (#2548).
+						if ( keystrokeActive ) {
+							return;
+						}
+
 						// Fix selection when non-editable element in Webkit/Blink (Mac) (https://dev.ckeditor.com/ticket/11306).
 						if ( CKEDITOR.env.mac && CKEDITOR.env.webkit ) {
 							var editor = this.editor,
@@ -69,8 +80,9 @@ CKEDITOR.plugins.add( 'contextmenu', {
 								}, true ); // Exclude editor's editable.
 
 							// Fake selection for non-editables only (to exclude nested editables).
-							if ( contentEditableParent && contentEditableParent.getAttribute( 'contenteditable' ) == 'false' )
+							if ( contentEditableParent && contentEditableParent.getAttribute( 'contenteditable' ) == 'false' ) {
 								editor.getSelection().fake( contentEditableParent );
+							}
 						}
 
 						var doc = domEvent.getTarget().getDocument(),
@@ -82,14 +94,12 @@ CKEDITOR.plugins.add( 'contextmenu', {
 
 						CKEDITOR.tools.setTimeout( function() {
 							this.open( offsetParent, null, offsetX, offsetY );
-
 							// IE needs a short while to allow selection change before opening menu. (https://dev.ckeditor.com/ticket/7908)
 						}, CKEDITOR.env.ie ? 200 : 0, this );
 					}, this );
 
 					if ( CKEDITOR.env.webkit ) {
-						var holdCtrlKey,
-							onKeyDown = function( event ) {
+						var onKeyDown = function( event ) {
 								holdCtrlKey = CKEDITOR.env.mac ? event.data.$.metaKey : event.data.$.ctrlKey;
 							},
 							resetOnKeyUp = function() {
@@ -100,6 +110,22 @@ CKEDITOR.plugins.add( 'contextmenu', {
 						element.on( 'keyup', resetOnKeyUp );
 						element.on( 'contextmenu', resetOnKeyUp );
 					}
+
+					// Block subsequent contextmenu event, when Shift + F10 is pressed (#2548).
+					if ( CKEDITOR.env.gecko && !CKEDITOR.env.mac ) {
+						element.on( 'keydown', function( evt ) {
+							if ( evt.data.$.shiftKey && evt.data.$.keyCode === 121 ) {
+								keystrokeActive = true;
+							}
+						}, null, null, 0 );
+
+						element.on( 'keyup', resetKeystrokeState );
+						element.on( 'contextmenu', resetKeystrokeState );
+					}
+
+					function resetKeystrokeState() {
+						keystrokeActive = false;
+					}
 				},
 
 				/**
@@ -111,7 +137,9 @@ CKEDITOR.plugins.add( 'contextmenu', {
 				 * @param {Number} [offsetY]
 				 */
 				open: function( offsetParent, corner, offsetX, offsetY ) {
-					if ( this.editor.config.enableContextMenu === false ) {
+					// Do not open context menu if it's disabled or there is no selection in the editor (#1181).
+					if ( this.editor.config.enableContextMenu === false ||
+						this.editor.getSelection().getType() === CKEDITOR.SELECTION_NONE ) {
 						return;
 					}
 
@@ -120,7 +148,6 @@ CKEDITOR.plugins.add( 'contextmenu', {
 
 					// https://dev.ckeditor.com/ticket/9362: Force selection check to update commands' states in the new context.
 					this.editor.selectionChange( 1 );
-
 					this.show( offsetParent, corner, offsetX, offsetY );
 				}
 			}
@@ -140,8 +167,23 @@ CKEDITOR.plugins.add( 'contextmenu', {
 		} );
 
 		editor.addCommand( 'contextMenu', {
-			exec: function() {
-				editor.contextMenu.open( editor.document.getBody() );
+			exec: function( editor ) {
+				var offsetX = 0,
+					offsetY = 0,
+					ranges = editor.getSelection().getRanges(),
+					rects,
+					rect;
+
+				// When opening context menu via keystroke there is no offsetX and Y passed (#1451).
+				rects = ranges[ ranges.length - 1 ].getClientRects( editor.editable().isInline() );
+				rect = rects[ rects.length - 1 ];
+
+				if ( rect ) {
+					offsetX = rect[ editor.lang.dir === 'rtl' ? 'left' : 'right' ];
+					offsetY = rect.bottom;
+				}
+
+				editor.contextMenu.open( editor.document.getBody().getParent(), null, offsetX, offsetY );
 			}
 		} );
 
@@ -155,7 +197,9 @@ CKEDITOR.plugins.add( 'contextmenu', {
  * <kbd>Meta</kbd> (Mac) key is pressed on opening the context menu with the
  * right mouse button click or the <kbd>Menu</kbd> key.
  *
- *		config.browserContextMenuOnCtrl = false;
+ * ```javascript
+ * config.browserContextMenuOnCtrl = false;
+ * ```
  *
  * @since 3.0.2
  * @cfg {Boolean} [browserContextMenuOnCtrl=true]
@@ -166,9 +210,24 @@ CKEDITOR.plugins.add( 'contextmenu', {
  * Whether to enable the context menu. Regardless of the setting the [Context Menu](https://ckeditor.com/cke4/addon/contextmenu)
  * plugin is still loaded.
  *
- *		config.enableContextMenu = false;
+ * ```javascript
+ * config.enableContextMenu = false;
+ * ```
  *
  * @since 4.7.0
  * @cfg {Boolean} [enableContextMenu=true]
  * @member CKEDITOR.config
  */
+
+/**
+ * The CSS file(s) to be used to apply the style to the context menu content.
+ *
+ * ```javascript
+ * config.contextmenu_contentsCss = '/css/myfile.css';
+ * config.contextmenu_contentsCss = [ '/css/myfile.css', '/css/anotherfile.css' ];
+ * ```
+ *
+ * @since 4.11.0
+ * @cfg {String/String[]} [contextmenu_contentsCss=CKEDITOR.skin.getPath( 'editor' )]
+ * @member CKEDITOR.config
+ */
