@@ -1,5 +1,5 @@
 ﻿/**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -7,7 +7,7 @@
 
 ( function() {
 	CKEDITOR.plugins.add( 'filetools', {
-		lang: 'az,ca,cs,da,de,de-ch,en,en-au,eo,es,es-mx,eu,fr,gl,hr,hu,id,it,ja,km,ko,ku,nb,nl,oc,pl,pt,pt-br,ro,ru,sk,sq,sv,tr,ug,uk,zh,zh-cn', // %REMOVE_LINE_CORE%
+		lang: 'az,bg,ca,cs,da,de,de-ch,en,en-au,eo,es,es-mx,et,eu,fa,fr,gl,hr,hu,id,it,ja,km,ko,ku,lv,nb,nl,no,oc,pl,pt,pt-br,ro,ru,sk,sq,sr,sr-latn,sv,tr,ug,uk,vi,zh,zh-cn', // %REMOVE_LINE_CORE%
 
 		beforeInit: function( editor ) {
 			/**
@@ -17,7 +17,7 @@
 			 *		var loader = editor.uploadRepository.create( file );
 			 *		loader.loadAndUpload( 'http://foo/bar' );
 			 *
-			 * @since 4.5
+			 * @since 4.5.0
 			 * @readonly
 			 * @property {CKEDITOR.fileTools.uploadRepository} uploadRepository
 			 * @member CKEDITOR.editor
@@ -27,9 +27,9 @@
 			/**
 			 * Event fired when the {@link CKEDITOR.fileTools.fileLoader file loader} should send XHR. If the event is not
 			 * {@link CKEDITOR.eventInfo#stop stopped} or {@link CKEDITOR.eventInfo#cancel canceled}, the default request
-			 * will be sent. Refer to the [Uploading Dropped or Pasted Files](#!/guide/dev_file_upload) article for more information.
+			 * will be sent. Refer to the {@glink guide/dev_file_upload Uploading Dropped or Pasted Files} article for more information.
 			 *
-			 * @since 4.5
+			 * @since 4.5.0
 			 * @event fileUploadRequest
 			 * @member CKEDITOR.editor
 			 * @param data
@@ -76,12 +76,12 @@
 			}, null, null, 999 );
 
 			/**
-			 * Event fired when the {CKEDITOR.fileTools.fileLoader file upload} response is received and needs to be parsed.
+			 * Event fired when the {@link CKEDITOR.fileTools.fileLoader file upload} response is received and needs to be parsed.
 			 * If the event is not {@link CKEDITOR.eventInfo#stop stopped} or {@link CKEDITOR.eventInfo#cancel canceled},
 			 * the default response handler will be used. Refer to the
-			 * [Uploading Dropped or Pasted Files](#!/guide/dev_file_upload) article for more information.
+			 * {@glink guide/dev_file_upload Uploading Dropped or Pasted Files} article for more information.
 			 *
-			 * @since 4.5
+			 * @since 4.5.0
 			 * @event fileUploadResponse
 			 * @member CKEDITOR.editor
 			 * @param data All data will be passed to {@link CKEDITOR.fileTools.fileLoader#responseData}.
@@ -133,7 +133,7 @@
 	 *
 	 * To find more information about handling files see the {@link CKEDITOR.fileTools.fileLoader} class.
 	 *
-	 * @since 4.5
+	 * @since 4.5.0
 	 * @class CKEDITOR.fileTools.uploadRepository
 	 * @mixins CKEDITOR.event
 	 * @constructor Creates an instance of the repository.
@@ -261,7 +261,7 @@
 	 *
 	 * Note that `FileLoader` uses the native file API which is supported **since Internet Explorer 10**.
 	 *
-	 * @since 4.5
+	 * @since 4.5.0
 	 * @class CKEDITOR.fileTools.fileLoader
 	 * @mixins CKEDITOR.event
 	 * @constructor Creates an instance of the class and sets initial values for all properties.
@@ -803,7 +803,7 @@
 		/**
 		 * Helpers to load and upload a file.
 		 *
-		 * @since 4.5
+		 * @since 4.5.0
 		 * @singleton
 		 * @class CKEDITOR.fileTools
 		 */
@@ -892,7 +892,7 @@
  *
  * An empty string means that the option is disabled.
  *
- * @since 4.5
+ * @since 4.5.0
  * @cfg {String} [uploadUrl='']
  * @member CKEDITOR.config
  */
@@ -917,7 +917,7 @@
  * Allows to add extra headers for every request made using the {@link CKEDITOR.fileTools} API.
  *
  * Note that headers can still be customized per a single request, using the
- * [`fileUploadRequest`](https://docs.ckeditor.com/ckeditor4/docs/#!/api/CKEDITOR.editor-event-fileUploadRequest)
+ * [`fileUploadRequest`](https://ckeditor.com/docs/ckeditor4/latest/api/CKEDITOR_editor.html#event-fileUploadRequest)
  * event.
  *
  *		config.fileTools_requestHeaders = {
