@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'iframe', 'de-ch', {
@@ -7,5 +7,6 @@ CKEDITOR.plugins.setLang( 'iframe', 'de-ch', {
 	noUrl: 'Bitte geben Sie die IFrame-URL an',
 	scrolling: 'Rollbalken anzeigen',
 	title: 'IFrame-Eigenschaften',
-	toolbar: 'IFrame'
+	toolbar: 'IFrame',
+	tabindex: 'Aus Tab-Reihenfolge entfernen'
 } );
