@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'iframe', 'pt-br', {
@@ -7,5 +7,6 @@ CKEDITOR.plugins.setLang( 'iframe', 'pt-br', {
 	noUrl: 'Insira a URL do iframe',
 	scrolling: 'Abilita scrollbars',
 	title: 'Propriedade do IFrame',
-	toolbar: 'IFrame'
+	toolbar: 'IFrame',
+	tabindex: 'Remove from tabindex' // MISSING
 } );
