@@ -1,8 +1,8 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'indent', 'sr', {
 	indent: 'Увећај леву маргину',
-	outdent: 'Смањи леву маргину'
+	outdent: 'Смањи маргину'
 } );
