@@ -1,13 +1,11 @@
-﻿/**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/**
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
 CKEDITOR.dialog.add( 'anchor', function( editor ) {
 	// Function called in onShow to load selected element.
 	var loadElements = function( element ) {
-			this._.selectedElement = element;
-
 			var attributeValue = element.data( 'cke-saved-name' );
 			this.setValueOf( 'info', 'txtName', attributeValue || '' );
 		};
@@ -27,6 +25,11 @@ CKEDITOR.dialog.add( 'anchor', function( editor ) {
 		range.shrink( CKEDITOR.SHRINK_ELEMENT );
 		element = range.getEnclosedNode();
 
+		// If selection is inside text, get its parent element (#3437).
+		if ( element && element.type === CKEDITOR.NODE_TEXT ) {
+			element = element.getParent();
+		}
+
 		if ( element && element.type === CKEDITOR.NODE_ELEMENT &&
 			( element.data( 'cke-real-element-type' ) === 'anchor' || element.is( 'a' ) ) ) {
 			return element;
@@ -37,25 +40,29 @@ CKEDITOR.dialog.add( 'anchor', function( editor ) {
 		title: editor.lang.link.anchor.title,
 		minWidth: 300,
 		minHeight: 60,
+		getModel: function( editor ) {
+			return getSelectedAnchor( editor.getSelection() ) || null;
+		},
 		onOk: function() {
-			var name = CKEDITOR.tools.trim( this.getValueOf( 'info', 'txtName' ) );
-			var attributes = {
-				id: name,
-				name: name,
-				'data-cke-saved-name': name
-			};
+			var name = CKEDITOR.tools.trim( this.getValueOf( 'info', 'txtName' ) ),
+				attributes = {
+					id: name,
+					name: name,
+					'data-cke-saved-name': name
+				},
+				selectedElement = this.getModel( editor );
 
-			if ( this._.selectedElement ) {
-				if ( this._.selectedElement.data( 'cke-realelement' ) ) {
+			if ( selectedElement ) {
+				if ( selectedElement.data( 'cke-realelement' ) ) {
 					var newFake = createFakeAnchor( editor, attributes );
-					newFake.replace( this._.selectedElement );
+					newFake.replace( selectedElement );
 
 					// Selecting fake element for IE. (https://dev.ckeditor.com/ticket/11377)
 					if ( CKEDITOR.env.ie ) {
 						editor.getSelection().selectElement( newFake );
 					}
 				} else {
-					this._.selectedElement.setAttributes( attributes );
+					selectedElement.setAttributes( attributes );
 				}
 			} else {
 				var sel = editor.getSelection(),
@@ -77,13 +84,9 @@ CKEDITOR.dialog.add( 'anchor', function( editor ) {
 			}
 		},
 
-		onHide: function() {
-			delete this._.selectedElement;
-		},
-
 		onShow: function() {
 			var sel = editor.getSelection(),
-				fullySelected = getSelectedAnchor( sel ),
+				fullySelected = this.getModel( editor ),
 				fakeSelected = fullySelected && fullySelected.data( 'cke-realelement' ),
 				linkElement = fakeSelected ?
 					CKEDITOR.plugins.link.tryRestoreFakeAnchor( editor, fullySelected ) :
@@ -92,10 +95,6 @@ CKEDITOR.dialog.add( 'anchor', function( editor ) {
 			if ( linkElement ) {
 				loadElements.call( this, linkElement );
 				!fakeSelected && sel.selectElement( linkElement );
-
-				if ( fullySelected ) {
-					this._.selectedElement = fullySelected;
-				}
 			}
 
 			this.getContentElement( 'info', 'txtName' ).focus();
