@@ -1,5 +1,5 @@
 ﻿/**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -35,8 +35,7 @@ CKEDITOR.plugins.removeformat = {
 					range;
 
 				while ( ( range = iterator.getNextRange() ) ) {
-					if ( !range.collapsed )
-						range.enlarge( CKEDITOR.ENLARGE_ELEMENT );
+					range.enlarge( CKEDITOR.ENLARGE_INLINE );
 
 					// Bookmark the range so we can re-select it after processing.
 					var bookmark = range.createBookmark(),
@@ -153,9 +152,9 @@ CKEDITOR.plugins.removeformat = {
  *			return !( element.is( 'span' ) && CKEDITOR.tools.isEmpty( element.getAttributes() ) );
  *		} );
  *
- * @since 3.3
+ * @since 3.3.0
  * @member CKEDITOR.editor
- * @param {Function} func The function to be called, which will be passed a {CKEDITOR.dom.element} element to test.
+ * @param {Function} func The function to be called, which will be passed an {@link CKEDITOR.dom.element element} to test.
  */
 CKEDITOR.editor.prototype.addRemoveFormatFilter = function( func ) {
 	if ( !this._.removeFormatFilters )
