@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'bg', {
@@ -11,14 +11,14 @@ CKEDITOR.plugins.setLang( 'table', 'bg', {
 		insertAfter: 'Вмъкване на клетка след',
 		deleteCell: 'Изтриване на клетки',
 		merge: 'Сливане на клетки',
-		mergeRight: 'Сливане в дясно',
-		mergeDown: 'Merge Down',
-		splitHorizontal: 'Split Cell Horizontally',
-		splitVertical: 'Split Cell Vertically',
+		mergeRight: 'Сливане надясно',
+		mergeDown: 'Сливане надолу',
+		splitHorizontal: 'Разделяне клетката хоризонтално',
+		splitVertical: 'Разделяне клетката вертикално',
 		title: 'Настройки на клетката',
 		cellType: 'Тип на клетката',
-		rowSpan: 'Rows Span',
-		colSpan: 'Columns Span',
+		rowSpan: 'Редове обединени',
+		colSpan: 'Колони обединени',
 		wordWrap: 'Авто. пренос',
 		hAlign: 'Хоризонтално подравняване',
 		vAlign: 'Вертикално подравняване',
@@ -26,17 +26,17 @@ CKEDITOR.plugins.setLang( 'table', 'bg', {
 		bgColor: 'Фон',
 		borderColor: 'Цвят на рамката',
 		data: 'Данни',
-		header: 'Хедър',
+		header: 'Заглавие',
 		yes: 'Да',
 		no: 'Не',
-		invalidWidth: 'Cell width must be a number.',
-		invalidHeight: 'Cell height must be a number.',
-		invalidRowSpan: 'Rows span must be a whole number.',
-		invalidColSpan: 'Columns span must be a whole number.',
+		invalidWidth: 'Ширината на клетката трябва да е число.',
+		invalidHeight: 'Височината на клетката трябва да е число.',
+		invalidRowSpan: 'Редове обединени трябва да е цяло число.',
+		invalidColSpan: 'Колони обединени трябва да е цяло число.',
 		chooseColor: 'Изберете'
 	},
 	cellPad: 'Отделяне на клетките',
-	cellSpace: 'Разтояние между клетките',
+	cellSpace: 'Разстояние между клетките',
 	column: {
 		menu: 'Колона',
 		insertBefore: 'Вмъкване на колона преди',
@@ -45,14 +45,15 @@ CKEDITOR.plugins.setLang( 'table', 'bg', {
 	},
 	columns: 'Колони',
 	deleteTable: 'Изтриване на таблица',
-	headers: 'Хедъри',
-	headersBoth: 'Заедно',
+	headers: 'Заглавия',
+	headersBoth: 'И двете',
 	headersColumn: 'Първа колона',
 	headersNone: 'Няма',
 	headersRow: 'Първи ред',
+	heightUnit: 'height unit', // MISSING
 	invalidBorder: 'Размерът на рамката трябва да е число.',
-	invalidCellPadding: 'Отстоянието на клетките трябва да е позитивно число.',
-	invalidCellSpacing: 'Интервала в клетките трябва да е позитивно число.',
+	invalidCellPadding: 'Отстоянието на клетките трябва да е положително число.',
+	invalidCellSpacing: 'Интервалът в клетките трябва да е положително число.',
 	invalidCols: 'Броят колони трябва да е по-голям от 0.',
 	invalidHeight: 'Височината на таблицата трябва да е число.',
 	invalidRows: 'Броят редове трябва да е по-голям от 0.',
