@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'en', {
@@ -50,6 +50,7 @@ CKEDITOR.plugins.setLang( 'table', 'en', {
 	headersColumn: 'First column',
 	headersNone: 'None',
 	headersRow: 'First Row',
+	heightUnit: 'height unit',
 	invalidBorder: 'Border size must be a number.',
 	invalidCellPadding: 'Cell padding must be a positive number.',
 	invalidCellSpacing: 'Cell spacing must be a positive number.',
