@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'zh-cn', {
@@ -50,6 +50,7 @@ CKEDITOR.plugins.setLang( 'table', 'zh-cn', {
 	headersColumn: '第一列',
 	headersNone: '无',
 	headersRow: '第一行',
+	heightUnit: '高度单位',
 	invalidBorder: '边框粗细必须为数字格式',
 	invalidCellPadding: '单元格填充必须为数字格式',
 	invalidCellSpacing: '单元格间距必须为数字格式',
