@@ -1,5 +1,5 @@
-﻿/**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/**
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -9,6 +9,7 @@
 	var fakeSelectedClass = 'cke_table-faked-selection',
 		fakeSelectedEditorClass = fakeSelectedClass + '-editor',
 		fakeSelectedTableDataAttribute = 'cke-table-faked-selection-table',
+		ignoredTableAttribute = 'data-cke-tableselection-ignored',
 		fakeSelection = { active: false },
 		tabletools,
 		getSelectedCells,
@@ -118,6 +119,7 @@
 
 	function clearFakeCellSelection( editor, reset ) {
 		var selectedCells = editor.editable().find( '.' + fakeSelectedClass ),
+			selectedTable = editor.editable().findOne( '[data-' + fakeSelectedTableDataAttribute + ']' ),
 			i;
 
 		editor.fire( 'lockSnapshot' );
@@ -128,8 +130,9 @@
 			selectedCells.getItem( i ).removeClass( fakeSelectedClass );
 		}
 
-		if ( selectedCells.count() > 0 ) {
-			selectedCells.getItem( 0 ).getAscendant( 'table' ).data( fakeSelectedTableDataAttribute, false );
+		// Table may be selected even though no cells are selected (e.g. after deleting cells.)
+		if ( selectedTable ) {
+			selectedTable.data( fakeSelectedTableDataAttribute, false );
 		}
 
 		editor.fire( 'unlockSnapshot' );
@@ -228,9 +231,11 @@
 		var editor = evt.editor || evt.sender.editor,
 			selection = editor && editor.getSelection(),
 			ranges = selection && selection.getRanges() || [],
+			enclosedNode = ranges && ranges[ 0 ].getEnclosedNode(),
+			isEnclosedNodeAnImage = enclosedNode && ( enclosedNode.type == CKEDITOR.NODE_ELEMENT ) && enclosedNode.is( 'img' ),
 			cells,
 			table,
-			i;
+			iterator;
 
 		if ( !selection ) {
 			return;
@@ -242,6 +247,17 @@
 			return;
 		}
 
+		// Don't perform fake selection when image is selected (#2235).
+		if ( isEnclosedNodeAnImage ) {
+			editor.getSelection().reset();
+			return;
+		}
+
+		// (#2945)
+		if ( ranges[ 0 ]._getTableElement( { table: 1 } ).hasAttribute( ignoredTableAttribute ) ) {
+			return;
+		}
+
 		// In case of whole nested table selection, getSelectedCells returns also
 		// cell which contains the table. We should filter it.
 		if ( ranges.length === 1 && ranges[ 0 ]._getTableElement() &&
@@ -253,8 +269,8 @@
 
 		editor.fire( 'lockSnapshot' );
 
-		for ( i = 0; i < cells.length; i++ ) {
-			cells[ i ].addClass( fakeSelectedClass );
+		for ( iterator = 0; iterator < cells.length; iterator++ ) {
+			cells[ iterator ].addClass( fakeSelectedClass );
 		}
 
 		if ( cells.length > 0 ) {
@@ -288,6 +304,11 @@
 			table = target && target.getAscendant( 'table', true ),
 			tableElements = { table: 1, thead: 1, tbody: 1, tfoot: 1, tr: 1, td: 1, th: 1 };
 
+		// (#2945)
+		if ( table && table.hasAttribute( ignoredTableAttribute ) ) {
+			return;
+		}
+
 		// Nested tables should be treated as the same one (e.g. user starts dragging from outer table
 		// and ends in inner one).
 		function isSameTable( selectedTable, table ) {
@@ -309,14 +330,19 @@
 				return true;
 			}
 
+			var isProperMouseEvent = evt.name === ( CKEDITOR.env.gecko ? 'mousedown' : 'mouseup' );
 			// Covers a case when:
 			// 1. User releases mouse button outside the table.
-			// 2. User opens context menu not in the selected table.
-			if ( evt.name === 'mouseup' && !isOutsideTable( evt.data.getTarget() ) && !isSameTable( selectedTable, table ) ) {
-				return true;
-			}
+			// 2. User opens context menu outside of selection.
+			// Use 'mousedown' for Firefox, as it doesn't fire 'mouseup' when mouse is released in context menu.
+			return isProperMouseEvent && !isOutsideTable( evt.data.getTarget() ) &&
+				!isInSelectedCell( evt.data.getTarget(), fakeSelectedClass );
+		}
 
-			return false;
+		function isInSelectedCell( target, fakeSelectedClass ) {
+			var cell = target.getAscendant( { td: 1, th: 1 }, true );
+
+			return cell && cell.hasClass( fakeSelectedClass );
 		}
 
 		if ( canClearSelection( evt, selection, selectedTable, table ) ) {
@@ -353,6 +379,13 @@
 	}
 
 	function fakeSelectionDragHandler( evt ) {
+		var table = evt.data.getTarget().getAscendant( 'table', true );
+
+		// (#2945)
+		if ( table && table.hasAttribute( ignoredTableAttribute ) ) {
+			return;
+		}
+
 		var cell = evt.data.getTarget().getAscendant( { td: 1, th: 1 }, true );
 
 		if ( !cell || cell.hasClass( fakeSelectedClass ) ) {
@@ -456,6 +489,12 @@
 			return;
 		}
 
+		// (#2945)
+		if ( selection.getRanges()[ 0 ]._getTableElement( { table: 1 } ).hasAttribute( ignoredTableAttribute ) ) {
+			return;
+		}
+
+
 		copyTable( editor, evt.name === 'cut' );
 	}
 
@@ -739,44 +778,20 @@
 		var editor = evt.editor,
 			selection = editor.getSelection(),
 			selectedCells = getSelectedCells( selection ),
-			pastedTable = this.findTableInPastedContent( editor, evt.data.dataValue ),
 			boundarySelection = selection.isInTable( true ) && this.isBoundarySelection( selection ),
+			pastedTable = this.findTableInPastedContent( editor, evt.data.dataValue ),
 			tableSel,
 			selectedTable,
 			selectedTableMap,
 			pastedTableMap;
 
-		function getLongestRowLength( map ) {
-			return Math.max.apply( null, CKEDITOR.tools.array.map( map, function( rowMap ) {
-				return rowMap.length;
-			}, 0 ) );
-		}
-
-		function selectCellContents( cell ) {
-			var range = editor.createRange();
-
-			range.selectNodeContents( cell );
-			range.select();
-		}
-
-		// Do not customize paste process in following cases:
-		// No cells are selected.
-		if ( !selectedCells.length ||
-			// It's single range that does not fully contain table element and is not boundary, e.g. collapsed selection within
-			// cell, part of cell etc.
-			( selectedCells.length === 1 && !rangeContainsTableElement( selection.getRanges()[ 0 ] )  && !boundarySelection ) ||
-			// It's a boundary position but with no table pasted.
-			( boundarySelection && !pastedTable ) ) {
+		if ( !isCustomPaste( selection, selectedCells, pastedTable, boundarySelection ) ) {
 			return;
 		}
 
 		selectedTable = selectedCells[ 0 ].getAscendant( 'table' );
 		tableSel = new TableSelection( getSelectedCells( selection, selectedTable ) );
 
-		function getLastArrayItem( arr ) {
-			return arr[ arr.length - 1 ];
-		}
-
 		// Schedule selecting appropriate table cells after pasting. It covers both table and not-table
 		// content (#520).
 		editor.once( 'afterPaste', function() {
@@ -788,6 +803,7 @@
 			fakeSelectCells( editor, toSelect );
 		} );
 
+
 		// In case of mixed content or non table content just select first cell, and erase content of other selected cells.
 		// Selection is left in first cell, so that default CKEditor logic puts pasted content in the selection (#520).
 		if ( !pastedTable ) {
@@ -842,6 +858,53 @@
 		setTimeout( function() {
 			editor.fire( 'afterPaste' );
 		}, 0 );
+
+		function isCustomPaste( selection, selectedCells, pastedTable, boundarySelection ) {
+			var ranges = selection.getRanges(),
+				table = ranges.length && ranges[ 0 ]._getTableElement( { table: 1 } );
+
+			// Do not customize paste process in following cases:
+			// 1. No cells are selected.
+			if ( !selectedCells.length ) {
+				return false;
+			}
+
+			// 2. Table is ignoring tableselection (#2945).
+			if ( table && table.hasAttribute( ignoredTableAttribute ) ) {
+				return false;
+			}
+
+			// 3. It's a boundary selection but with no table pasted.
+			if ( boundarySelection && !pastedTable ) {
+				return false;
+			}
+
+			// 4. It isn't a boundary selection (if it is, at this point we know that table is pasted so it should be
+			// handled by custom paste to correctly insert rows etc.) and it either exceeds table or doesn't contain
+			// whole table cell (#875).
+			if ( !boundarySelection && !rangeContainsTableElement( ranges[ 0 ] ) ) {
+				return false;
+			}
+
+			return true;
+		}
+
+		function getLastArrayItem( arr ) {
+			return arr[ arr.length - 1 ];
+		}
+
+		function selectCellContents( cell ) {
+			var range = editor.createRange();
+
+			range.selectNodeContents( cell );
+			range.select();
+		}
+
+		function getLongestRowLength( map ) {
+			return Math.max.apply( null, CKEDITOR.tools.array.map( map, function( rowMap ) {
+				return rowMap.length;
+			}, 0 ) );
+		}
 	}
 
 	function customizeTableCommand( editor, cmds, callback ) {
@@ -859,14 +922,24 @@
 	}
 
 	/**
-	 * Namespace providing a set of helper functions for working with tables, exposed by
+	 * Namespace providing a set of helper functions for working with tables, exposed by the
 	 * [Table Selection](https://ckeditor.com/cke4/addon/tableselection) plugin.
 	 *
+	 * **Note:** Since 4.12.0 you can use the `cke-tableselection-ignored` attribute to disable
+	 * the table selection feature for the given table.
+	 *
+	 * ```javascript
+	 * var table = new CKEDITOR.dom.element( 'table' );
+	 *
+	 * table.data( 'cke-tableselection-ignored', 1 );
+	 * ```
+	 *
 	 * @since 4.7.0
 	 * @singleton
 	 * @class CKEDITOR.plugins.tableselection
 	 */
 	CKEDITOR.plugins.tableselection = {
+
 		/**
 		 * Fetches all cells between cells passed as parameters, including these cells.
 		 *
@@ -883,7 +956,7 @@
 		 * @private
 		 */
 		keyboardIntegration: function( editor ) {
-			// Handle left, up, right, down, delete and backspace keystrokes inside table fake selection.
+			// Handle left, up, right, down, delete, backspace and enter keystrokes inside table fake selection.
 			function getTableOnKeyDownListener( editor ) {
 				var keystrokes = {
 						37: 1, // Left Arrow
@@ -891,7 +964,8 @@
 						39: 1, // Right Arrow,
 						40: 1, // Down Arrow
 						8: 1, // Backspace
-						46: 1 // Delete
+						46: 1, // Delete
+						13: 1 // Enter
 					},
 					tags = CKEDITOR.tools.extend( { table: 1 }, CKEDITOR.dtd.$tableContent );
 
@@ -963,16 +1037,18 @@
 				return function( evt ) {
 					// Use getKey directly in order to ignore modifiers.
 					// Justification: https://dev.ckeditor.com/ticket/11861#comment:13
-					var keystroke = evt.data.getKey(),
+					var key = evt.data.getKey(),
+						keystroke = evt.data.getKeystroke(),
 						selection,
-						toStart = keystroke === 37 || keystroke == 38,
+						toStart = key === 37 || key == 38,
 						ranges,
 						firstCell,
 						lastCell,
 						i;
 
 					// Handle only left/right/del/bspace keys.
-					if ( !keystrokes[ keystroke ] ) {
+					// Disable editing cells in readonly mode (#1489).
+					if ( !keystrokes[ key ] || editor.readOnly ) {
 						return;
 					}
 
@@ -986,15 +1062,24 @@
 					firstCell = ranges[ 0 ]._getTableElement();
 					lastCell = ranges[ ranges.length - 1 ]._getTableElement();
 
-					evt.data.preventDefault();
-					evt.cancel();
+					// Only prevent event when tableselection handle it. Which is non-enter button, or pressing enter button with enterkey plugin present (#1816).
+					if ( key !== 13 || editor.plugins.enterkey ) {
+						evt.data.preventDefault();
+						evt.cancel();
+					}
 
-					if ( keystroke > 8 && keystroke < 46 ) {
+					if ( key > 36 && key < 41 ) {
 						// Arrows.
 						ranges[ 0 ].moveToElementEditablePosition( toStart ? firstCell : lastCell, !toStart );
 						selection.selectRanges( [ ranges[ 0 ] ] );
 					} else {
-						// Delete.
+						// Delete, backspace, enter.
+
+						// Do nothing for Enter with modifiers different than shift.
+						if ( key === 13 && !( keystroke === 13 || keystroke === CKEDITOR.SHIFT + 13 ) ) {
+							return;
+						}
+
 						for ( i = 0; i < ranges.length; i++ ) {
 							clearCellInRange( ranges[ i ] );
 						}
@@ -1009,7 +1094,17 @@
 						}
 
 						selection.selectRanges( ranges );
-						editor.fire( 'saveSnapshot' );
+
+						if ( key === 13 && editor.plugins.enterkey ) {
+							// We need to lock undoManager to consider clearing table and inserting new paragraph as single operation, and have only one undo step (#1816).
+							editor.fire( 'lockSnapshot' );
+							keystroke === 13 ? editor.execCommand( 'enter' ) : editor.execCommand( 'shiftEnter' );
+							editor.fire( 'unlockSnapshot' );
+							editor.fire( 'saveSnapshot' );
+						} else if ( key !== 13 ) {
+							// Backspace and delete key should have saved snapshot.
+							editor.fire( 'saveSnapshot' );
+						}
 					}
 				};
 			}
@@ -1022,6 +1117,11 @@
 					firstCell,
 					i;
 
+				// Disable editing cells in readonly mode (#1489).
+				if ( editor.readOnly ) {
+					return;
+				}
+
 				// We must check if the event really did not produce any character as it's fired for all keys in Gecko.
 				if ( !selection || !selection.isInTable() || !selection.isFake || !isCharKey ||
 					evt.data.getKeystroke() & CKEDITOR.CTRL ) {
@@ -1046,8 +1146,9 @@
 				var node = range.getEnclosedNode();
 
 				// Set text only in case of table cells, otherwise remove whole element (#867).
-				if ( node && node.is( { td: 1, th: 1 } ) ) {
-					range.getEnclosedNode().setText( '' );
+				// Check if `node.is` is function, as returned node might be CKEDITOR.dom.text (#2089).
+				if ( node && typeof node.is === 'function' && node.is( { td: 1, th: 1 } ) ) {
+					node.setText( '' );
 				} else {
 					range.deleteContents();
 				}
@@ -1064,20 +1165,16 @@
 			var editable = editor.editable();
 			editable.attachListener( editable, 'keydown', getTableOnKeyDownListener( editor ), null, null, -1 );
 			editable.attachListener( editable, 'keypress', tableKeyPressListener, null, null, -1 );
-		},
-
-		/**
-		 * Determines whether table selection is supported in the current environment.
-		 *
-		 * @property {Boolean}
-		 * @private
-		 */
-		isSupportedEnvironment: !( CKEDITOR.env.ie && CKEDITOR.env.version < 11 )
+		}
 	};
 
 	CKEDITOR.plugins.add( 'tableselection', {
 		requires: 'clipboard,tabletools',
 
+		isSupportedEnvironment: function() {
+			return !( CKEDITOR.env.ie && CKEDITOR.env.version < 11 );
+		},
+
 		onLoad: function() {
 			// We can't alias these features earlier, as they could be still not loaded.
 			tabletools = CKEDITOR.plugins.tabletools;
@@ -1091,7 +1188,7 @@
 
 		init: function( editor ) {
 			// Disable unsupported browsers.
-			if ( !CKEDITOR.plugins.tableselection.isSupportedEnvironment ) {
+			if ( !this.isSupportedEnvironment() ) {
 				return;
 			}
 
