@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'toolbar', 'bg', {
@@ -8,7 +8,7 @@ CKEDITOR.plugins.setLang( 'toolbar', 'bg', {
 	toolbarGroups: {
 		document: 'Документ',
 		clipboard: 'Клипборд/Отмяна',
-		editing: 'Промяна',
+		editing: 'Редакция',
 		forms: 'Форми',
 		basicstyles: 'Базови стилове',
 		paragraph: 'Параграф',
