@@ -22,7 +22,7 @@ use ServerProfilePersistenceManager;
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
-                2005 - 2022  Roland Gruber
+                2005 - 2023  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -174,7 +174,7 @@ if (isset($_POST['language'])) {
 	}
 }
 
-$_SESSION['header'] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
+$_SESSION['header'] = "<!DOCTYPE html>\n\n";
 $_SESSION['header'] .= "<html>\n<head>\n";
 $_SESSION['header'] .= "<meta name=\"robots\" content=\"noindex, nofollow\">\n";
 $_SESSION['header'] .= "<meta http-equiv=\"content-type\" content=\"text/html; charset=" . $encoding . "\">\n";
@@ -210,8 +210,12 @@ function display_LoginPage(?LAMLicenseValidator $licenseValidator, ?string $erro
     // save both in cookie
 	$cookieOptions = lamDefaultCookieOptions();
 	$cookieOptions['expires'] = 0;
-    setcookie("Key", base64_encode($key), $cookieOptions);
-    setcookie("IV", base64_encode($iv), $cookieOptions);
+	if ($key !== false) {
+		setcookie("Key", base64_encode($key), $cookieOptions);
+    }
+	if ($iv !== false) {
+		setcookie("IV", base64_encode($iv), $cookieOptions);
+    }
 
 	$serverProfilePersistenceManager = new ServerProfilePersistenceManager();
 	$profiles = $serverProfilePersistenceManager->getProfiles();
@@ -225,7 +229,7 @@ function display_LoginPage(?LAMLicenseValidator $licenseValidator, ?string $erro
 	// include all JavaScript files
 	printJsIncludes('..');
 
-	if (isLAMProVersion() && $licenseValidator->isEvaluationLicense()) {
+	if (isLAMProVersion() && ($licenseValidator !== null) && $licenseValidator->isEvaluationLicense()) {
 		StatusMessage('INFO', _('Evaluation Licence'));
 	}
 	displayLoginHeader();
@@ -256,39 +260,12 @@ function display_LoginPage(?LAMLicenseValidator $licenseValidator, ?string $erro
 			StatusMessage("ERROR", _("Your session expired, please log in again."));
 			echo "<br>";
 		}
-		// check if main config was saved
-		if (isset($_GET['confMainSavedOk'])) {
-			StatusMessage("INFO", _("Your settings were successfully saved."));
-			echo "<br>";
-		}
-		// check if a server profile was saved
-		if (isset($_GET['configSaveOk'])) {
-			StatusMessage("INFO", _("Your settings were successfully saved."), htmlspecialchars($_GET['configSaveFile']));
-			echo "<br>";
-		}
-		elseif (isset($_GET['configSaveFailed'])) {
-			StatusMessage("ERROR", _("Cannot open config file!"), htmlspecialchars($_GET['configSaveFile']));
-			echo "<br>";
-		}
-		// check if self service was saved
-		if (isset($_GET['selfserviceSaveOk'])) {
-			StatusMessage("INFO", _("Your settings were successfully saved."), htmlspecialchars($_GET['selfserviceSaveOk']));
-			echo "<br>";
-		}
-		if (isset($_GET['2factor']) && ($_GET['2factor'] == 'error')) {
-			StatusMessage('ERROR', _("Unable to start 2-factor authentication."));
-			echo "<br>";
-		}
-		elseif (isset($_GET['2factor']) && ($_GET['2factor'] == 'noToken')) {
-			StatusMessage('ERROR', _("Unable to start 2-factor authentication because no tokens were found."));
-			echo "<br>";
-		}
 		if (!empty($config_object)) {
 		?>
 		<br><br><br>
 		<div class="centeredTable">
 		<div class="roundedShadowBox limitWidth" style="position:relative; z-index:5;">
-		<table border="0" rules="none" bgcolor="white" class="ui-corner-all">
+		<table border="0" rules="none" bgcolor="white">
 			<tr>
 				<td style="border-style:none">
 					<form action="login.php" method="post">
@@ -446,8 +423,8 @@ function display_LoginPage(?LAMLicenseValidator $licenseValidator, ?string $erro
 		}
 		?>
 		<br><br>
-		<?PHP
-			if (isLAMProVersion() && $licenseValidator->isExpiringSoon()) {
+		<?php
+			if (isLAMProVersion() && ($licenseValidator !== null) && $licenseValidator->isExpiringSoon()) {
 				$expirationDate = $licenseValidator->getLicense()->getExpirationDate()->format('Y-m-d');
 				$expirationTimeStamp = $licenseValidator->getLicense()->getExpirationDate()->getTimestamp();
 				if ($cfgMain->showLicenseWarningOnScreen()) {
@@ -569,12 +546,24 @@ if (isset($_POST['checklogin'])) {
                     cleanLDAPResult($searchInfo);
                     if (empty($searchInfo)) {
                         $searchSuccess = false;
-                        $searchError = _('Wrong password/user name combination. Please try again.');
+                        if ($default_Config->isHideLoginErrorDetails()) {
+							$searchError = _('Wrong password/user name combination. Please try again.');
+                        }
+                        else {
+							$searchError = _('Unable to find the user name in LDAP.');
+                        }
+						logNewMessage(LOG_ERR, 'User ' . $username . ' (' . $clientSource . ') failed to log in. Unable to find the user name in LDAP.');
 	                    header("HTTP/1.1 403 Forbidden");
                     }
                     elseif (sizeof($searchInfo) > 1) {
                         $searchSuccess = false;
-                        $searchError = _('The given user name matches multiple LDAP entries.');
+						if ($default_Config->isHideLoginErrorDetails()) {
+							$searchError = _('Wrong password/user name combination. Please try again.');
+						}
+						else {
+							$searchError = _('The given user name matches multiple LDAP entries.');
+						}
+						logNewMessage(LOG_ERR, 'User ' . $username . ' (' . $clientSource . ') failed to log in. The given user name matches multiple LDAP entries.');
 	                    header("HTTP/1.1 403 Forbidden");
                     }
                     else {
@@ -583,16 +572,28 @@ if (isset($_POST['checklogin'])) {
                 }
                 else {
                     $searchSuccess = false;
-                    $searchError = _('Unable to find the user name in LDAP.');
+					if ($default_Config->isHideLoginErrorDetails()) {
+						$searchError = _('Wrong password/user name combination. Please try again.');
+					}
+					else {
+						$searchError = _('Unable to find the user name in LDAP.');
+					}
 	                header("HTTP/1.1 403 Forbidden");
                     if (ldap_errno($searchLDAP->server()) != 0) {
                         $searchError .= ' ' . getDefaultLDAPErrorString($searchLDAP->server());
                     }
+					logNewMessage(LOG_ERR, 'User ' . $username . ' (' . $clientSource . ') failed to log in. Unable to find the user name in LDAP.');
                 }
             }
             else {
                 $searchSuccess = false;
-                $searchError = _('Unable to find the user name in LDAP.');
+				if ($default_Config->isHideLoginErrorDetails()) {
+					$searchError = _('Wrong password/user name combination. Please try again.');
+				}
+				else {
+					$searchError = _('Unable to find the user name in LDAP.');
+				}
+				logNewMessage(LOG_ERR, 'User ' . $username . ' (' . $clientSource . ') failed to log in. Unable to find the user name in LDAP.');
 	            header("HTTP/1.1 403 Forbidden");
                 if (ldap_errno($searchLDAP->server()) != 0) {
                     $searchError .= ' ' . getDefaultLDAPErrorString($searchLDAP->server());
@@ -600,7 +601,6 @@ if (isset($_POST['checklogin'])) {
             }
 			if (!$searchSuccess) {
 				$error_message = $searchError;
-				logNewMessage(LOG_ERR, 'User ' . $username . ' (' . $clientSource . ') failed to log in. ' . $searchError . '');
 				$searchLDAP->close();
 				display_LoginPage($licenseValidator, $error_message);
 				exit();
@@ -638,10 +638,16 @@ if (isset($_POST['checklogin'])) {
 		header("HTTP/1.1 403 Forbidden");
 		$extraMessage = null;
 		if (($searchLDAP !== null) && ($e->getLdapErrorCode() == 49)) {
-			$extraMessage = getExtraInvalidCredentialsMessage($searchLDAP->server(), $username);
+		    if (!$default_Config->isHideLoginErrorDetails()) {
+				$extraMessage = getExtraInvalidCredentialsMessage($searchLDAP->server(), $username);
+			}
 			$searchLDAP->close();
 		}
-		display_LoginPage($licenseValidator, $e->getTitle(), $e->getMessage(), $extraMessage);
+		$message = $e->getMessage();
+		if ($default_Config->isHideLoginErrorDetails()) {
+		    $message = null;
+		}
+		display_LoginPage($licenseValidator, $e->getTitle(), $message, $extraMessage);
 		exit();
     }
 }
