@@ -104,13 +104,9 @@ class Ajax {
 			die();
 		}
 		$function = $_GET['function'];
-		if (!isset($_POST['jsonInput'])) {
-			die();
-		}
 
-		$jsonInput = $_POST['jsonInput'];
-		if ($function == 'passwordStrengthCheck') {
-			$this->checkPasswordStrength($jsonInput);
+		if (($function === 'passwordStrengthCheck') && isset($_POST['jsonInput'])) {
+			$this->checkPasswordStrength(json_decode($_POST['jsonInput'], true));
 			die();
 		}
 		if ($function === 'webauthn') {
@@ -124,8 +120,8 @@ class Ajax {
 			die();
 		}
 		enforceUserIsLoggedIn();
-		if ($function == 'passwordChange') {
-			$this->managePasswordChange($jsonInput);
+		if (($function === 'passwordChange') && isset($_POST['jsonInput'])) {
+			$this->managePasswordChange(json_decode($_POST['jsonInput'], true));
 		}
 		elseif ($function === 'import') {
 			include_once('../../lib/import.inc');
@@ -196,7 +192,7 @@ class Ajax {
 	 *
 	 * @param array<mixed> $input input parameters
 	 */
-	private static function managePasswordChange($input): void {
+	private static function managePasswordChange(array $input): void {
 		$sessionKey  = htmlspecialchars($_GET['editKey']);
 		$return = $_SESSION[$sessionKey]->setNewPassword($input);
 		echo json_encode($return);
@@ -207,7 +203,7 @@ class Ajax {
 	 *
 	 * @param array<mixed> $input input parameters
 	 */
-	private function checkPasswordStrength($input): void {
+	private function checkPasswordStrength(array $input): void {
 		$password = $input['password'];
 		$result = checkPasswordStrength($password, null, null);
 		echo json_encode(array("result" => $result));
