@@ -230,10 +230,16 @@ if (!empty($_POST['export'])) {
 if (isset($_POST['uploadLogo']) && !empty($_FILES['logoUpload']) && !empty($_FILES['logoUpload']['size'])) {
 	$file = $_FILES['logoUpload']['tmp_name'];
 	$handle = fopen($file, "r");
-	$data = fread($handle, 100000000);
-	fclose($handle);
-	$filename = $_FILES['logoUpload']['name'];
 	try {
+		if ($handle === false) {
+			throw new LAMException(_('Unable to create temporary file.'));
+		}
+        $data = fread($handle, 100000000);
+		if ($data === false) {
+			throw new LAMException(_('Unable to create temporary file.'));
+		}
+        fclose($handle);
+        $filename = $_FILES['logoUpload']['name'];
 		$pdfStructurePersistenceManager->savePdfLogo($_SESSION['config']->getName(), $filename, $data);
 		$container->add(new htmlStatusMessage('INFO', _('Uploaded logo file.'), $filename), 12);
     }
@@ -627,28 +633,20 @@ if (!empty($globalDeletableTemplates)) {
     $container = new htmlResponsiveRow();
 	$globalTemplatesSubtitle = new htmlSubTitle(_('Global templates'));
 	$globalTemplatesSubtitle->setHelpId('364');
-    $container->add($globalTemplatesSubtitle, 12);
+    $container->add($globalTemplatesSubtitle);
     $globalTemplatesSelect = new htmlResponsiveSelect('globalTemplatesDelete', $globalDeletableTemplates, array(), _('Delete'));
     $globalTemplatesSelect->setContainsOptgroups(true);
     $globalTemplatesSelect->setHasDescriptiveElements(true);
-    $container->add($globalTemplatesSelect, 12);
-    $globalTemplateDeleteDialogPassword = new htmlResponsiveInputField(_("Master password"), 'globalTemplateDeletePassword', null, '236');
-    $globalTemplateDeleteDialogPassword->setIsPassword(true);
-    $globalTemplateDeleteDialogPassword->setRequired(true);
-    $container->add($globalTemplateDeleteDialogPassword, 12);
+    $container->add($globalTemplatesSelect);
     $container->addVerticalSpacer('1rem');
     $globalTemplateDeleteButton = new htmlButton('deleteGlobalProfileButton', _('Delete'));
     $globalTemplateDeleteButton->setCSSClasses(array('lam-danger'));
-    $globalTemplateDeleteButton->setOnClick("showConfirmationDialog('" . _("Delete") . "', '" .
-        _('Ok') . "', '" . _('Cancel') . "', 'globalTemplateDeleteDialog', 'deleteGlobalTemplatesForm', undefined); return false;");
+    $globalTemplateDeleteButton->setOnClick("window.lam.dialog.requestPasswordAndSendForm('" . _('Do you really want to delete this profile?') . "', '" .
+        _('Ok') . "', '" . _('Cancel') . "', '" . _('Master password') . "', 'globalTemplateDeletePassword', 'deleteGlobalTemplatesForm'); return false;");
     $container->addLabel(new htmlOutputText('&nbsp;', false));
-    $container->addField($globalTemplateDeleteButton, 12);
+    $container->addField($globalTemplateDeleteButton);
     addSecurityTokenToMetaHTML($container);
-    $globalTemplateDeleteDialogContent = new htmlResponsiveRow();
-    $globalTemplateDeleteDialogContent->add(new htmlOutputText(_('Do you really want to delete this profile?')), 12);
-    $globalTemplateDeleteDialogContent->add(new htmlHiddenInput('deleteGlobalTemplate', 'true'), 12);
-    $globalTemplateDeleteDialogDiv = new htmlDiv('globalTemplateDeleteDialog', $globalTemplateDeleteDialogContent, array('hidden'));
-    $container->add($globalTemplateDeleteDialogDiv, 12);
+    $container->add(new htmlHiddenInput('deleteGlobalTemplate', 'true'));
     $container->addVerticalSpacer('1rem');
     $globalTemplateDeleteForm = new htmlForm('deleteGlobalTemplatesForm', 'pdfmain.php', $container);
     parseHtml(null, $globalTemplateDeleteForm, array(), false, $tabindex, 'user');
@@ -660,26 +658,18 @@ if (!empty($globalPdfLogos)) {
 	$container = new htmlResponsiveRow();
 	$globalLogosSubtitle = new htmlSubTitle(_('Global template logos'));
 	$globalLogosSubtitle->setHelpId('365');
-	$container->add($globalLogosSubtitle, 12);
+	$container->add($globalLogosSubtitle);
 	$globalTemplateLogosSelect = new htmlResponsiveSelect('globalLogoDelete', $globalPdfLogos, array(), _('Delete'));
-	$container->add($globalTemplateLogosSelect, 12);
-	$globalLogoDeleteDialogPassword = new htmlResponsiveInputField(_("Master password"), 'globalLogoDeletePassword', null, '236');
-	$globalLogoDeleteDialogPassword->setIsPassword(true);
-	$globalLogoDeleteDialogPassword->setRequired(true);
-	$container->add($globalLogoDeleteDialogPassword, 12);
+	$container->add($globalTemplateLogosSelect);
 	$container->addVerticalSpacer('1rem');
 	$globalLogoDeleteButton = new htmlButton('deleteGlobalLogoButton', _('Delete'));
 	$globalLogoDeleteButton->setCSSClasses(array('lam-danger'));
-	$globalLogoDeleteButton->setOnClick("showConfirmationDialog('" . _("Delete") . "', '" .
-		_('Ok') . "', '" . _('Cancel') . "', 'globalLogoDeleteDialog', 'deleteGlobalLogoForm', undefined); return false;");
+	$globalLogoDeleteButton->setOnClick("window.lam.dialog.requestPasswordAndSendForm('" . _('Do you really want to delete this logo?') . "', '" .
+		_('Ok') . "', '" . _('Cancel') . "', '" . _('Master password') . "', 'globalLogoDeletePassword', 'deleteGlobalLogoForm'); return false;");
 	$container->addLabel(new htmlOutputText('&nbsp;', false));
-	$container->addField($globalLogoDeleteButton, 12);
+	$container->addField($globalLogoDeleteButton);
 	addSecurityTokenToMetaHTML($container);
-	$globalLogoDeleteDialogContent = new htmlResponsiveRow();
-	$globalLogoDeleteDialogContent->add(new htmlOutputText(_('Do you really want to delete this logo?')), 12);
-	$globalLogoDeleteDialogContent->add(new htmlHiddenInput('deleteGlobalLogo', 'true'), 12);
-	$globalLogoDeleteDialogDiv = new htmlDiv('globalLogoDeleteDialog', $globalLogoDeleteDialogContent, array('hidden'));
-	$container->add($globalLogoDeleteDialogDiv, 12);
+	$container->add(new htmlHiddenInput('deleteGlobalLogo', 'true'));
 	$container->addVerticalSpacer('1rem');
 	$globalLogoDeleteForm = new htmlForm('deleteGlobalLogoForm', 'pdfmain.php', $container);
 	parseHtml(null, $globalLogoDeleteForm, array(), false, $tabindex, 'user');
