@@ -256,15 +256,13 @@ $saveButton->setCSSClasses(array('lam-primary fullwidth-mobile-only'));
 $buttonTable->addLabel($saveButton);
 $cancelButton = new htmlButton('abort', _('Cancel'));
 $cancelButton->setCSSClasses(array('fullwidth-mobile-only'));
+$cancelButton->disableFormValidation();
 $buttonTable->addField($cancelButton);
 $buttonTable->add(new htmlHiddenInput('accounttype', $type->getId()), 0);
 
 $_SESSION['profile_types'] = array_merge($_SESSION['profile_types'], parseHtml(null, $buttonTable, $old_options, false, $tabindex, $type->getScope()));
 
 ?>
-<script type="text/javascript">
-	jQuery("#profilepage").validationEngine({promptPosition: "topLeft", addFailureCssClassToField: "lam-input-error", autoHidePrompt: true, autoHideDelay: 5000});
-</script>
 </form>
 </div>
 <?php
