@@ -75,11 +75,13 @@ function showTree(): void {
 			if ((strlen($initialDn) > strlen($rootDn)) && substr($initialDn, -1 * strlen($rootDn)) === $rootDn) {
 				$extraDnPart = substr($initialDn, 0, (-1 * strlen($rootDn)) - 1);
 				$dnParts = ldap_explode_dn($extraDnPart, 0);
-				unset($dnParts['count']);
-				$dnPartsCount = sizeof($dnParts);
-				for ($i = 0; $i < $dnPartsCount; $i++) {
-					$currentParts = array_slice($dnParts, $dnPartsCount - ($i + 1));
-					$openInitial[] = '"' . base64_encode(implode(',', $currentParts) . ',' . $rootDn) . '"';
+				if ($dnParts !== false) {
+					unset($dnParts['count']);
+					$dnPartsCount = sizeof($dnParts);
+					for ($i = 0; $i < $dnPartsCount; $i++) {
+						$currentParts = array_slice($dnParts, $dnPartsCount - ($i + 1));
+						$openInitial[] = '"' . base64_encode(implode(',', $currentParts) . ',' . $rootDn) . '"';
+					}
 				}
 			}
 		}
@@ -257,16 +259,13 @@ function showTree(): void {
 	$pwdCheckRow = new htmlResponsiveRow();
 	$pwdCheckInput = new htmlResponsiveInputField(_('Password'), 'lam_pwd_check');
 	$pwdCheckInput->setIsPassword(true);
+	$pwdCheckInput->setCSSClasses(array('lam_pwd_check'));
 	$pwdCheckRow->add($pwdCheckInput);
 	$pwdCheckRow->addVerticalSpacer('1rem');
 	$pwdCheckRow->add(new htmlDiv('lam-pwd-check-dialog-result', new htmlGroup()));
 	$pwdCheckDiv = new htmlDiv('lam-pwd-check-dialog', $pwdCheckRow, array('hidden'));
 	$row->add($pwdCheckDiv);
 
-	$row->add(new htmlJavaScript('jQuery(document).ready(function() {
-					jQuery(\'form[name="actionarea"]\').validationEngine({promptPosition: "topLeft", addFailureCssClassToField: "lam-input-error", autoHidePrompt: true, autoHideDelay: 5000});
-				});'), 12);
-
 	$tabIndex = 1;
 	$form = new htmlForm('actionarea', 'treeView.php', $row);
 	parseHtml(null, $form, array(), true, $tabIndex, null);
