@@ -10,7 +10,7 @@ use \htmlResponsiveRow;
 /*
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2022  Roland Gruber
+  Copyright (C) 2004 - 2023  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -131,8 +131,10 @@ if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
 	$handle = fopen ($_FILES['inputfile']['tmp_name'], "r");
 	if ($handle !== false) {
 		if (($head = fgetcsv($handle, 2000)) !== false ) { // head row
-			foreach ($head as $i => $headItem) {
-				$ids[$headItem] = $i;
+			if ($head !== false) {
+				foreach ($head as $i => $headItem) {
+					$ids[$headItem] = $i;
+				}
 			}
 		}
 		while (($line = fgetcsv($handle, 2000)) !== false ) { // account rows
@@ -193,7 +195,7 @@ if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
 			if (sizeof($values_given) != sizeof($values_unique)) {
 				$duplicates = array();
 				foreach ($values_given as $key => $value) {
-					if (!isset($values_unique[$key])) {
+					if (!isset($values_unique[$key]) && ($value !== null)) {
 						$duplicates[] = htmlspecialchars($value);
 					}
 				}
@@ -266,7 +268,7 @@ if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
 					$_SESSION['mass_pdf']['structure'] = $_POST['pdfStructure'];
 					$_SESSION['mass_pdf']['font'] = $_POST['pdf_font'];
 					$_SESSION['mass_pdf']['counter'] = 0;
-					$_SESSION['mass_pdf']['file'] = '../../tmp/lam_pdf' . getRandomNumber() . '.zip';
+					$_SESSION['mass_pdf']['file'] = '../../tmp/lam_pdf_' . generateRandomText() . '.zip';
 				}
 				else {
 					$_SESSION['mass_pdf']['structure'] = null;
